@@ -119,7 +119,7 @@ m.Template = m.Class({
 	},
 
 	"techCostMultiplier": function(type) {
-		return +(this.get("ProductionQueue/TechCostMultiplier/"+type) || 1);
+		return +(this.get("Researcher/TechCostMultiplier/"+type) || 1);
 	},
 
 	/**
@@ -340,14 +340,14 @@ m.Template = m.Class({
 	},
 
 	"trainableEntities": function(civ) {
-		let templates = this.get("ProductionQueue/Entities/_string");
+		const templates = this.get("Trainer/Entities/_string");
 		if (!templates)
 			return undefined;
 		return templates.replace(/\{native\}/g, this.civ()).replace(/\{civ\}/g, civ).split(/\s+/);
 	},
 
 	"researchableTechs": function(gameState, civ) {
-		let templates = this.get("ProductionQueue/Technologies/_string");
+		const templates = this.get("Researcher/Technologies/_string");
 		if (!templates)
 			return undefined;
 		let techs = templates.split(/\s+/);
@@ -452,10 +452,10 @@ m.Template = m.Class({
 
 	"trainingCategory": function() { return this.get("TrainingRestrictions/Category"); },
 
-	"buildTime": function(productionQueue) {
+	"buildTime": function(researcher) {
 		let time = +this.get("Cost/BuildTime");
-		if (productionQueue)
-			time *= productionQueue.techCostMultiplier("time");
+		if (researcher)
+			time *= researcher.techCostMultiplier("time");
 		return time;
 	},
 
@@ -590,6 +590,8 @@ m.Entity = m.Class({
 		this._entityModif = sharedAI._entitiesModifications.get(entity.id);
 	},
 
+	"queryInterface": function(iid) { return SimEngine.QueryInterface(this.id(), iid) },
+
 	"toString": function() { return "[Entity " + this.id() + " " + this.templateName() + "]"; },
 
 	"id": function() { return this._entity.id; },
@@ -679,24 +681,25 @@ m.Entity = m.Class({
 	},
 
 	"resourceSupplyAmount": function() {
-		return this._entity.resourceSupplyAmount;
+		return this.queryInterface(Sim.IID_ResourceSupply)?.GetCurrentAmount();
 	},
 
 	"resourceSupplyNumGatherers": function()
 	{
-		return this._entity.resourceSupplyNumGatherers;
+		return this.queryInterface(Sim.IID_ResourceSupply)?.GetNumGatherers();
 	},
 
 	"isFull": function()
 	{
-		if (this._entity.resourceSupplyNumGatherers !== undefined)
-			return this.maxGatherers() === this._entity.resourceSupplyNumGatherers;
+		let numGatherers = this.resourceSupplyNumGatherers();
+		if (numGatherers)
+			return this.maxGatherers() === numGatherers;
 
 		return undefined;
 	},
 
 	"resourceCarrying": function() {
-		return this._entity.resourceCarrying;
+		return this.queryInterface(Sim.IID_ResourceGatherer)?.GetCarryingStatus();
 	},
 
 	"currentGatherRate": function() {
@@ -814,10 +817,10 @@ m.Entity = m.Class({
 	},
 
 	// violent, aggressive, defensive, passive, standground
-	"setStance": function(stance, queued = false, pushFront = false) {
+	"setStance": function(stance) {
 		if (this.getStance() === undefined)
 			return undefined;
-		Engine.PostCommand(PlayerID, { "type": "stance", "entities": [this.id()], "name": stance, "queued": queued, "pushFront": pushFront });
+		Engine.PostCommand(PlayerID, { "type": "stance", "entities": [this.id()], "name": stance});
 		return this;
 	},
 
@@ -940,7 +943,7 @@ m.Entity = m.Class({
 		return this;
 	},
 
-	"train": function(civ, type, count, metadata, promotedTypes)
+	"train": function(civ, type, count, metadata, pushFront = false)
 	{
 		let trainable = this.trainableEntities(civ);
 		if (!trainable)
@@ -960,7 +963,7 @@ m.Entity = m.Class({
 			"template": type,
 			"count": count,
 			"metadata": metadata,
-			"promoted": promotedTypes
+			"pushFront": pushFront
 		});
 		return this;
 	},
@@ -985,8 +988,13 @@ m.Entity = m.Class({
 		return this;
 	},
 
-	"research": function(template) {
-		Engine.PostCommand(PlayerID, { "type": "research", "entity": this.id(), "template": template });
+	"research": function(template, pushFront = false) {
+		Engine.PostCommand(PlayerID, {
+			"type": "research",
+			"entity": this.id(),
+			"template": template,
+			"pushFront": pushFront
+		});
 		return this;
 	},
 
