@@ -4,13 +4,12 @@
  * To making sure units are built, and pushing elements to the queue manager otherwise
  * It also handles the actual attack, though much work is needed on that.
  */
-
-PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
+PETRA.AttackPlan = function(gameState, Config, uniqueID, type = PETRA.AttackPlan.TYPE_DEFAULT, data)
 {
 	this.Config = Config;
 	this.name = uniqueID;
-	this.type = type || "Attack";
-	this.state = "unexecuted";
+	this.type = type;
+	this.state = PETRA.AttackPlan.STATE_UNEXECUTED;
 	this.forced = false;  // true when this attacked has been forced to help an ally
 
 	if (data && data.target)
@@ -32,7 +31,7 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 	let rallyPoint;
 	let rallyAccess;
 	let allAccesses = {};
-	for (let base of gameState.ai.HQ.baseManagers)
+	for (const base of gameState.ai.HQ.baseManagers())
 	{
 		if (!base.anchor || !base.anchor.position())
 			continue;
@@ -114,7 +113,7 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 	this.unitStat = {};
 
 	// neededShips is the minimal number of ships which should be available for transport
-	if (type == "Rush")
+	if (type === PETRA.AttackPlan.TYPE_RUSH)
 	{
 		priority = 250;
 		this.unitStat.Infantry = { "priority": 1, "minSize": 10, "targetSize": 20, "batchSize": 2, "classes": ["Infantry"],
@@ -125,14 +124,14 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 			this.unitStat.Infantry.targetSize = data.targetSize;
 		this.neededShips = 1;
 	}
-	else if (type == "Raid")
+	else if (type === PETRA.AttackPlan.TYPE_RAID)
 	{
 		priority = 150;
 		this.unitStat.FastMoving = { "priority": 1, "minSize": 3, "targetSize": 4, "batchSize": 2, "classes": ["FastMoving+CitizenSoldier"],
 			"interests": [ ["strength", 1] ] };
 		this.neededShips = 1;
 	}
-	else if (type == "HugeAttack")
+	else if (type === PETRA.AttackPlan.TYPE_HUGE_ATTACK)
 	{
 		priority = 90;
 		// basically we want a mix of citizen soldiers so our barracks have a purpose, and champion units.
@@ -171,18 +170,18 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 	// Put some randomness on the attack size
 	let variation = randFloat(0.8, 1.2);
 	// and lower priority and smaller sizes for easier difficulty levels
-	if (this.Config.difficulty < 2)
+	if (this.Config.difficulty < PETRA.DIFFICULTY_EASY)
 	{
 		priority *= 0.4;
 		variation *= 0.2;
 	}
-	else if (this.Config.difficulty < 3)
+	else if (this.Config.difficulty < PETRA.DIFFICULTY_MEDIUM)
 	{
 		priority *= 0.8;
 		variation *= 0.6;
 	}
 
-	if (this.Config.difficulty < 2)
+	if (this.Config.difficulty < PETRA.DIFFICULTY_EASY)
 	{
 		for (const cat in this.unitStat)
 		{
@@ -216,7 +215,7 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 	// each array is [ratio, [associated classes], associated EntityColl, associated unitStat, name ]
 	this.buildOrders = [];
 	this.canBuildUnits = gameState.ai.HQ.canBuildUnits;
-	this.siegeState = 0;	// 0 = not yet tested, 1 = not yet any siege trainer, 2 = siege added in build orders
+	this.siegeState = PETRA.AttackPlan.SIEGE_NOT_TESTED;
 
 	// some variables used during the attack
 	this.position5TurnsAgo = [0, 0];
@@ -227,6 +226,27 @@ PETRA.AttackPlan = function(gameState, Config, uniqueID, type, data)
 	return true;
 };
 
+PETRA.AttackPlan.PREPARATION_FAILED = 0;
+PETRA.AttackPlan.PREPARATION_KEEP_GOING = 1;
+PETRA.AttackPlan.PREPARATION_START = 2;
+
+PETRA.AttackPlan.SIEGE_NOT_TESTED = 0;
+PETRA.AttackPlan.SIEGE_NO_TRAINER = 1;
+
+/**
+ * Siege added in build orders
+ */
+PETRA.AttackPlan.SIEGE_ADDED = 2;
+
+PETRA.AttackPlan.STATE_UNEXECUTED = "unexecuted";
+PETRA.AttackPlan.STATE_COMPLETING = "completing";
+PETRA.AttackPlan.STATE_ARRIVED = "arrived";
+
+PETRA.AttackPlan.TYPE_DEFAULT = "Attack";
+PETRA.AttackPlan.TYPE_HUGE_ATTACK = "HugeAttack";
+PETRA.AttackPlan.TYPE_RAID = "Raid";
+PETRA.AttackPlan.TYPE_RUSH = "Rush";
+
 PETRA.AttackPlan.prototype.init = function(gameState)
 {
 	this.queue = gameState.ai.queues["plan_" + this.name];
@@ -262,7 +282,7 @@ PETRA.AttackPlan.prototype.getType = function()
 
 PETRA.AttackPlan.prototype.isStarted = function()
 {
-	return this.state !== "unexecuted" && this.state !== "completing";
+	return this.state !== PETRA.AttackPlan.STATE_UNEXECUTED && this.state !== PETRA.AttackPlan.STATE_COMPLETING;
 };
 
 PETRA.AttackPlan.prototype.isPaused = function()
@@ -316,7 +336,7 @@ PETRA.AttackPlan.prototype.mustStart = function()
 	if (MaxReachedEverywhere)
 		return true;
 	if (MinReachedEverywhere)
-		return this.type == "Raid" && this.target && this.target.foundationProgress() &&
+		return this.type === PETRA.AttackPlan.TYPE_RAID && this.target && this.target.foundationProgress() &&
 		                                             this.target.foundationProgress() > 50;
 	return false;
 };
@@ -364,7 +384,7 @@ PETRA.AttackPlan.prototype.addBuildOrder = function(gameState, name, unitStats,
 
 PETRA.AttackPlan.prototype.addSiegeUnits = function(gameState)
 {
-	if (this.siegeState == 2 || this.state !== "unexecuted")
+	if (this.siegeState === PETRA.AttackPlan.SIEGE_ADDED || this.state !== PETRA.AttackPlan.STATE_UNEXECUTED)
 		return false;
 
 	let civ = gameState.getPlayerCiv();
@@ -388,7 +408,10 @@ PETRA.AttackPlan.prototype.addSiegeUnits = function(gameState)
 		}
 	}
 	if (hasTrainer.every(e => !e))
+	{
+		this.siegeState = PETRA.AttackPlan.SIEGE_NO_TRAINER;
 		return false;
+	}
 	let i = this.name % classes.length;
 	for (let k = 0; k < classes.length; ++k)
 	{
@@ -397,13 +420,13 @@ PETRA.AttackPlan.prototype.addSiegeUnits = function(gameState)
 		i = ++i % classes.length;
 	}
 
-	this.siegeState = 2;
+	this.siegeState = PETRA.AttackPlan.SIEGE_ADDED;
 	let targetSize;
-	if (this.Config.difficulty < 3)
-		targetSize = this.type == "HugeAttack" ? Math.max(this.Config.difficulty, 1) : Math.max(this.Config.difficulty - 1, 0);
+	if (this.Config.difficulty < PETRA.DIFFICULTY_MEDIUM)
+		targetSize = this.type === PETRA.AttackPlan.TYPE_HUGE_ATTACK ? Math.max(this.Config.difficulty, 1) : Math.max(this.Config.difficulty - 1, 0);
 	else
-		targetSize = this.type == "HugeAttack" ? this.Config.difficulty + 1 : this.Config.difficulty - 1;
-	targetSize = Math.max(Math.round(this.Config.popScaling * targetSize), this.type == "HugeAttack" ? 1 : 0);
+		targetSize = this.type === PETRA.AttackPlan.TYPE_HUGE_ATTACK ? this.Config.difficulty + 1 : this.Config.difficulty - 1;
+	targetSize = Math.max(Math.round(this.Config.popScaling * targetSize), this.type === PETRA.AttackPlan.TYPE_HUGE_ATTACK ? 1 : 0);
 	if (!targetSize)
 		return true;
 	// no minsize as we don't want the plan to fail at the last minute though.
@@ -418,23 +441,23 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 {
 	// the completing step is used to return resources and regroup the units
 	// so we check that we have no more forced order before starting the attack
-	if (this.state == "completing")
+	if (this.state === PETRA.AttackPlan.STATE_COMPLETING)
 	{
 		// if our target was destroyed, go back to "unexecuted" state
 		if (this.targetPlayer === undefined || !this.target || !gameState.getEntityById(this.target.id()))
 		{
-			this.state = "unexecuted";
+			this.state = PETRA.AttackPlan.STATE_UNEXECUTED;
 			this.target = undefined;
 		}
 		else
 		{
 			// check that all units have finished with their transport if needed
 			if (this.waitingForTransport())
-				return 1;
+				return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
 			// bloqued units which cannot finish their order should not stop the attack
 			if (gameState.ai.elapsedTime < this.maxCompletingTime && this.hasForceOrder())
-				return 1;
-			return 2;
+				return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
+			return PETRA.AttackPlan.PREPARATION_START;
 		}
 	}
 
@@ -443,11 +466,11 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 
 	// if we need a transport, wait for some transport ships
 	if (this.overseas && !gameState.ai.HQ.navalManager.seaTransportShips[this.overseas].length)
-		return 1;
+		return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
 
-	if (this.type != "Raid" || !this.forced)    // Forced Raids have special purposes (as relic capture)
+	if (this.type !== PETRA.AttackPlan.TYPE_RAID || !this.forced)    // Forced Raids have special purposes (as relic capture)
 		this.assignUnits(gameState);
-	if (this.type != "Raid" && gameState.ai.HQ.attackManager.getAttackInPreparation("Raid") !== undefined)
+	if (this.type !== PETRA.AttackPlan.TYPE_RAID && gameState.ai.HQ.attackManager.getAttackInPreparation(PETRA.AttackPlan.TYPE_RAID) !== undefined)
 		this.reassignFastUnit(gameState);    // reassign some fast units (if any) to fasten raid preparations
 
 	// Fasten the end game.
@@ -481,16 +504,16 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 			if (this.Config.debug > 1)
 			{
 				let am = gameState.ai.HQ.attackManager;
-				API3.warn(" attacks upcoming: raid " + am.upcomingAttacks.Raid.length +
-					  " rush " + am.upcomingAttacks.Rush.length +
-					  " attack " + am.upcomingAttacks.Attack.length +
-					  " huge " + am.upcomingAttacks.HugeAttack.length);
-				API3.warn(" attacks started: raid " + am.startedAttacks.Raid.length +
-					  " rush " + am.startedAttacks.Rush.length +
-					  " attack " + am.startedAttacks.Attack.length +
-					  " huge " + am.startedAttacks.HugeAttack.length);
+				API3.warn(" attacks upcoming: raid " + am.upcomingAttacks[PETRA.AttackPlan.TYPE_RAID].length +
+					  " rush " + am.upcomingAttacks[PETRA.AttackPlan.TYPE_RUSH].length +
+					  " attack " + am.upcomingAttacks[PETRA.AttackPlan.TYPE_DEFAULT].length +
+					  " huge " + am.upcomingAttacks[PETRA.AttackPlan.TYPE_HUGE_ATTACK].length);
+				API3.warn(" attacks started: raid " + am.startedAttacks[PETRA.AttackPlan.TYPE_RAID].length +
+					  " rush " + am.startedAttacks[PETRA.AttackPlan.TYPE_RUSH].length +
+					  " attack " + am.startedAttacks[PETRA.AttackPlan.TYPE_DEFAULT].length +
+					  " huge " + am.startedAttacks[PETRA.AttackPlan.TYPE_HUGE_ATTACK].length);
 			}
-			return 0;
+			return PETRA.AttackPlan.PREPARATION_FAILED;
 		}
 	}
 	else if (this.mustStart())
@@ -499,7 +522,7 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 		{
 			// keep on while the units finish being trained, then we'll start
 			this.emptyQueues();
-			return 1;
+			return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
 		}
 	}
 	else
@@ -507,30 +530,31 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 		if (this.canBuildUnits)
 		{
 			// We still have time left to recruit units and do stuffs.
-			if (this.siegeState == 0 || this.siegeState == 1 && gameState.ai.playedTurn % 5 == 0)
+			if (this.siegeState === PETRA.AttackPlan.SIEGE_NOT_TESTED ||
+				this.siegeState === PETRA.AttackPlan.SIEGE_NO_TRAINER && gameState.ai.playedTurn % 5 == 0)
 				this.addSiegeUnits(gameState);
 			this.trainMoreUnits(gameState);
 			// may happen if we have no more training facilities and build orders are canceled
 			if (!this.buildOrders.length)
-				return 0;	// will abort the plan
+				return PETRA.AttackPlan.PREPARATION_FAILED;	// will abort the plan
 		}
-		return 1;
+		return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
 	}
 
 	// if we're here, it means we must start
-	this.state = "completing";
+	this.state = PETRA.AttackPlan.STATE_COMPLETING;
 
 	// Raids have their predefined target
 	if (!this.target && !this.chooseTarget(gameState))
-		return 0;
+		return PETRA.AttackPlan.PREPARATION_FAILED;
 	if (!this.overseas)
 		this.getPathToTarget(gameState);
 
-	if (this.type == "Raid")
+	if (this.type === PETRA.AttackPlan.TYPE_RAID)
 		this.maxCompletingTime = this.forced ? 0 : gameState.ai.elapsedTime + 20;
 	else
 	{
-		if (this.type == "Rush" || this.forced)
+		if (this.type === PETRA.AttackPlan.TYPE_RUSH || this.forced)
 			this.maxCompletingTime = gameState.ai.elapsedTime + 40;
 		else
 			this.maxCompletingTime = gameState.ai.elapsedTime + 60;
@@ -562,8 +586,8 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 			ent.setMetadata(PlayerID, "plan", -1);
 			continue;
 		}
-		ent.setMetadata(PlayerID, "role", "attack");
-		ent.setMetadata(PlayerID, "subrole", "completing");
+		ent.setMetadata(PlayerID, "role", PETRA.Worker.ROLE_ATTACK);
+		ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_COMPLETING);
 		let queued = false;
 		if (ent.resourceCarrying() && ent.resourceCarrying().length)
 			queued = PETRA.returnResources(gameState, ent);
@@ -576,7 +600,7 @@ PETRA.AttackPlan.prototype.updatePreparation = function(gameState)
 
 	// reset all queued units
 	this.removeQueues(gameState);
-	return	1;
+	return PETRA.AttackPlan.PREPARATION_KEEP_GOING;
 };
 
 PETRA.AttackPlan.prototype.trainMoreUnits = function(gameState)
@@ -651,7 +675,7 @@ PETRA.AttackPlan.prototype.trainMoreUnits = function(gameState)
 				let max = firstOrder[3].batchSize;
 				let specialData = "Plan_" + this.name + "_" + firstOrder[4];
 				let data = { "plan": this.name, "special": specialData, "base": 0 };
-				data.role = gameState.getTemplate(template).hasClass("CitizenSoldier") ? "worker" : "attack";
+				data.role = gameState.getTemplate(template).hasClass("CitizenSoldier") ? PETRA.Worker.ROLE_WORKER : PETRA.Worker.ROLE_ATTACK;
 				let trainingPlan = new PETRA.TrainingPlan(gameState, template, data, max, max);
 				if (trainingPlan.template)
 					queue.addPlan(trainingPlan);
@@ -681,7 +705,7 @@ PETRA.AttackPlan.prototype.assignUnits = function(gameState)
 		return added;
 	}
 
-	if (this.type == "Raid")
+	if (this.type === PETRA.AttackPlan.TYPE_RAID)
 	{
 		// Raids are quick attacks: assign all FastMoving soldiers except some for hunting.
 		let num = 0;
@@ -722,15 +746,15 @@ PETRA.AttackPlan.prototype.assignUnits = function(gameState)
 	// Finally add also some workers for the higher difficulties,
 	// If Rush, assign all kind of workers, keeping only a minimum number of defenders
 	// Otherwise, assign only some idle workers if too much of them
-	if (this.Config.difficulty <= 2)
+	if (this.Config.difficulty <= PETRA.DIFFICULTY_EASY)
 		return added;
 
 	let num = 0;
 	const numbase = {};
-	let keep = this.type != "Rush" ?
+	let keep = this.type !== PETRA.AttackPlan.TYPE_RUSH ?
 		6 + 4 * gameState.getNumPlayerEnemies() + 8 * this.Config.personality.defensive : 8;
 	keep = Math.round(this.Config.popScaling * keep);
-	for (const ent of gameState.getOwnEntitiesByRole("worker", true).values())
+	for (const ent of gameState.getOwnEntitiesByRole(PETRA.Worker.ROLE_WORKER, true).values())
 	{
 		if (!ent.hasClass("CitizenSoldier") || !this.isAvailableUnit(gameState, ent))
 			continue;
@@ -745,7 +769,7 @@ PETRA.AttackPlan.prototype.assignUnits = function(gameState)
 		}
 		if (num++ < keep || numbase[baseID] < 5)
 			continue;
-		if (this.type != "Rush" && ent.getMetadata(PlayerID, "subrole") != "idle")
+		if (this.type !== PETRA.AttackPlan.TYPE_RUSH && ent.getMetadata(PlayerID, "subrole") !== PETRA.Worker.SUBROLE_IDLE)
 			continue;
 		ent.setMetadata(PlayerID, "plan", plan);
 		this.unitCollection.updateEnt(ent);
@@ -775,7 +799,7 @@ PETRA.AttackPlan.prototype.reassignFastUnit = function(gameState)
 			continue;
 		if (!ent.hasClasses(["FastMoving", "CitizenSoldier"]))
 			continue;
-		let raid = gameState.ai.HQ.attackManager.getAttackInPreparation("Raid");
+		const raid = gameState.ai.HQ.attackManager.getAttackInPreparation(PETRA.AttackPlan.TYPE_RAID);
 		ent.setMetadata(PlayerID, "plan", raid.name);
 		this.unitCollection.updateEnt(ent);
 		raid.unitCollection.updateEnt(ent);
@@ -816,7 +840,7 @@ PETRA.AttackPlan.prototype.chooseTarget = function(gameState)
 		let rallySame;
 		let distminDiff = Math.min();
 		let rallyDiff;
-		for (let base of gameState.ai.HQ.baseManagers)
+		for (const base of gameState.ai.HQ.baseManagers())
 		{
 			let anchor = base.anchor;
 			if (!anchor || !anchor.position())
@@ -887,9 +911,9 @@ PETRA.AttackPlan.prototype.getNearestTarget = function(gameState, position, same
 	}
 	else
 	{
-		if (this.type == "Raid")
+		if (this.type === PETRA.AttackPlan.TYPE_RAID)
 			targets = this.raidTargetFinder(gameState);
-		else if (this.type == "Rush" || this.type == "Attack")
+		else if (this.type === PETRA.AttackPlan.TYPE_RUSH || this.type === PETRA.AttackPlan.TYPE_DEFAULT)
 		{
 			targets = this.rushTargetFinder(gameState, this.targetPlayer);
 			if (!targets.hasEntities() && (this.hasSiegeUnits() || this.forced))
@@ -914,7 +938,7 @@ PETRA.AttackPlan.prototype.getNearestTarget = function(gameState, position, same
 			continue;
 		let dist = API3.SquareVectorDistance(ent.position(), position);
 		// In normal attacks, disfavor fields
-		if (this.type != "Rush" && this.type != "Raid" && ent.hasClass("Field"))
+		if (this.type !== PETRA.AttackPlan.TYPE_RUSH && this.type !== PETRA.AttackPlan.TYPE_RAID && ent.hasClass("Field"))
 			dist += 100000;
 		if (dist < minDist)
 		{
@@ -1034,7 +1058,7 @@ PETRA.AttackPlan.prototype.rushTargetFinder = function(gameState, playerEnemy)
 	if (target)
 		targets.addEnt(target);
 
-	if (!targets.hasEntities() && this.type == "Rush" && playerEnemy)
+	if (!targets.hasEntities() && this.type === PETRA.AttackPlan.TYPE_RUSH && playerEnemy)
 		targets = this.rushTargetFinder(gameState);
 
 	return targets;
@@ -1232,7 +1256,7 @@ PETRA.AttackPlan.prototype.StartAttack = function(gameState)
 
 	for (let ent of this.unitCollection.values())
 	{
-		ent.setMetadata(PlayerID, "subrole", "walking");
+		ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_WALKING);
 		let stance = ent.isPackable() ? "standground" : "aggressive";
 		if (ent.getStance() != stance)
 			ent.setStance(stance);
@@ -1285,16 +1309,16 @@ PETRA.AttackPlan.prototype.update = function(gameState, events)
 		return 0;
 	}
 
-	if (this.state == "arrived")
+	if (this.state === PETRA.AttackPlan.STATE_ARRIVED)
 	{
 		// let's proceed on with whatever happens now.
 		this.state = "";
 		this.startingAttack = true;
 		this.unitCollection.forEach(ent => {
 			ent.stopMoving();
-			ent.setMetadata(PlayerID, "subrole", "attacking");
+			ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_ATTACKING);
 		});
-		if (this.type == "Rush")   // try to find a better target for rush
+		if (this.type === PETRA.AttackPlan.TYPE_RUSH)   // try to find a better target for rush
 		{
 			let newtarget = this.getNearestTarget(gameState, this.position);
 			if (newtarget)
@@ -1450,7 +1474,7 @@ PETRA.AttackPlan.prototype.update = function(gameState, events)
 
 		let targetClassesUnit;
 		let targetClassesSiege;
-		if (this.type == "Rush")
+		if (this.type === PETRA.AttackPlan.TYPE_RUSH)
 			targetClassesUnit = { "attack": ["Unit", "Structure"], "avoid": ["Palisade", "Wall", "Tower", "Fortress"], "vetoEntities": veto };
 		else
 		{
@@ -1767,7 +1791,7 @@ PETRA.AttackPlan.prototype.UpdateTransporting = function(gameState, events)
 
 	if (done)
 	{
-		this.state = "arrived";
+		this.state = PETRA.AttackPlan.STATE_ARRIVED;
 		return;
 	}
 
@@ -1818,7 +1842,7 @@ PETRA.AttackPlan.prototype.UpdateWalking = function(gameState, events)
 	{
 		if (gameState.ai.HQ.territoryMap.getOwner(this.position) === this.targetPlayer || attackedNB > 3)
 		{
-			this.state = "arrived";
+			this.state = PETRA.AttackPlan.STATE_ARRIVED;
 			return true;
 		}
 	}
@@ -1858,7 +1882,7 @@ PETRA.AttackPlan.prototype.UpdateWalking = function(gameState, events)
 			{
 				if (this.Config.debug > 1)
 					API3.warn("Attack Plan " + this.type + " " + this.name + " has met walls and is not happy.");
-				this.state = "arrived";
+				this.state = PETRA.AttackPlan.STATE_ARRIVED;
 				return true;
 			}
 			// abort plan
@@ -1876,7 +1900,7 @@ PETRA.AttackPlan.prototype.UpdateWalking = function(gameState, events)
 	{
 		if (this.Config.debug > 1)
 			API3.warn("Attack Plan " + this.type + " " + this.name + " has arrived to destination.");
-		this.state = "arrived";
+		this.state = PETRA.AttackPlan.STATE_ARRIVED;
 		return true;
 	}
 	else if (this.path.length && API3.SquareVectorDistance(this.position, this.path[0]) < 1600)
@@ -1888,7 +1912,7 @@ PETRA.AttackPlan.prototype.UpdateWalking = function(gameState, events)
 		{
 			if (this.Config.debug > 1)
 				API3.warn("Attack Plan " + this.type + " " + this.name + " has arrived to destination.");
-			this.state = "arrived";
+			this.state = PETRA.AttackPlan.STATE_ARRIVED;
 			return true;
 		}
 	}
@@ -2001,7 +2025,7 @@ PETRA.AttackPlan.prototype.Abort = function(gameState)
 				dist = API3.SquareVectorDistance(this.position, rallyPoint);
 			}
 			// Then check if we have a nearer base (in case this attack has captured one)
-			for (let base of gameState.ai.HQ.baseManagers)
+			for (const base of gameState.ai.HQ.baseManagers())
 			{
 				if (!base.anchor || !base.anchor.position())
 					continue;
@@ -2017,7 +2041,7 @@ PETRA.AttackPlan.prototype.Abort = function(gameState)
 
 		for (let ent of this.unitCollection.values())
 		{
-			if (ent.getMetadata(PlayerID, "role") == "attack")
+			if (ent.getMetadata(PlayerID, "role") === PETRA.Worker.ROLE_ATTACK)
 				ent.stopMoving();
 			if (rallyPoint)
 				ent.moveToRange(rallyPoint[0], rallyPoint[1], 0, 15);
@@ -2033,10 +2057,10 @@ PETRA.AttackPlan.prototype.Abort = function(gameState)
 
 PETRA.AttackPlan.prototype.removeUnit = function(ent, update)
 {
-	if (ent.getMetadata(PlayerID, "role") == "attack")
+	if (ent.getMetadata(PlayerID, "role") === PETRA.Worker.ROLE_ATTACK)
 	{
 		if (ent.hasClass("CitizenSoldier"))
-			ent.setMetadata(PlayerID, "role", "worker");
+			ent.setMetadata(PlayerID, "role", PETRA.Worker.ROLE_WORKER);
 		else
 			ent.setMetadata(PlayerID, "role", undefined);
 		ent.setMetadata(PlayerID, "subrole", undefined);
@@ -2052,7 +2076,7 @@ PETRA.AttackPlan.prototype.checkEvents = function(gameState, events)
 	{
 		if (!this.target || this.target.id() != evt.entity)
 			continue;
-		if (this.type == "Raid" && !this.isStarted())
+		if (this.type === PETRA.AttackPlan.TYPE_RAID && !this.isStarted())
 			this.target = undefined;
 		else
 			this.target = gameState.getEntityById(evt.newentity);
@@ -2072,7 +2096,7 @@ PETRA.AttackPlan.prototype.checkEvents = function(gameState, events)
 		this.target = undefined;
 	}
 
-	if (!this.overseas || this.state !== "unexecuted")
+	if (!this.overseas || this.state !== PETRA.AttackPlan.STATE_UNEXECUTED)
 		return;
 	// let's check if an enemy has built a structure at our access
 	for (let evt of events.Create)
@@ -2083,7 +2107,7 @@ PETRA.AttackPlan.prototype.checkEvents = function(gameState, events)
 		if (!gameState.isPlayerEnemy(ent.owner()))
 			continue;
 		let access = PETRA.getLandAccess(gameState, ent);
-		for (let base of gameState.ai.HQ.baseManagers)
+		for (const base of gameState.ai.HQ.baseManagers())
 		{
 			if (!base.anchor || !base.anchor.position())
 				continue;
