@@ -10,10 +10,11 @@
  *  -updating whatever needs updating, keeping track of stuffs (rebuilding needs…)
  */
 
-PETRA.BaseManager = function(gameState, Config)
+PETRA.BaseManager = function(gameState, basesManager)
 {
-	this.Config = Config;
+	this.Config = basesManager.Config;
 	this.ID = gameState.ai.uniqueIDs.bases++;
+	this.basesManager = basesManager;
 
 	// anchor building: seen as the main building of the base. Needs to have territorial influence
 	this.anchor = undefined;
@@ -26,7 +27,7 @@ PETRA.BaseManager = function(gameState, Config)
 
 	this.constructing = false;
 	// Defenders to train in this cc when its construction is finished
-	this.neededDefenders = this.Config.difficulty > 2 ? 3 + 2*(this.Config.difficulty - 3) : 0;
+	this.neededDefenders = this.Config.difficulty > PETRA.DIFFICULTY_EASY ? 3 + 2*(this.Config.difficulty - 3) : 0;
 
 	// vector for iterating, to check one use the HQ map.
 	this.territoryIndices = [];
@@ -34,16 +35,34 @@ PETRA.BaseManager = function(gameState, Config)
 	this.timeNextIdleCheck = 0;
 };
 
+
+PETRA.BaseManager.STATE_WITH_ANCHOR = "anchored";
+
+/**
+ * New base with a foundation anchor.
+ */
+PETRA.BaseManager.STATE_UNCONSTRUCTED = "unconstructed";
+
+/**
+ * Captured base with an anchor.
+ */
+PETRA.BaseManager.STATE_CAPTURED = "captured";
+
+/**
+ * Anchorless base, currently with dock.
+ */
+PETRA.BaseManager.STATE_ANCHORLESS = "anchorless";
+
 PETRA.BaseManager.prototype.init = function(gameState, state)
 {
-	if (state == "unconstructed")
+	if (state === PETRA.BaseManager.STATE_UNCONSTRUCTED)
 		this.constructing = true;
-	else if (state != "captured")
+	else if (state !== PETRA.BaseManager.STATE_CAPTURED)
 		this.neededDefenders = 0;
 	this.workerObject = new PETRA.Worker(this);
 	// entitycollections
 	this.units = gameState.getOwnUnits().filter(API3.Filters.byMetadata(PlayerID, "base", this.ID));
-	this.workers = this.units.filter(API3.Filters.byMetadata(PlayerID, "role", "worker"));
+	this.workers = this.units.filter(API3.Filters.byMetadata(PlayerID, "role", PETRA.Worker.ROLE_WORKER));
 	this.buildings = gameState.getOwnStructures().filter(API3.Filters.byMetadata(PlayerID, "base", this.ID));
 	this.mobileDropsites = this.units.filter(API3.Filters.isDropsite());
 
@@ -65,12 +84,11 @@ PETRA.BaseManager.prototype.init = function(gameState, state)
 
 PETRA.BaseManager.prototype.reset = function(gameState, state)
 {
-	if (state == "unconstructed")
+	if (state === PETRA.BaseManager.STATE_UNCONSTRUCTED)
 		this.constructing = true;
 	else
 		this.constructing = false;
-
-	if (state != "captured" || this.Config.difficulty < 3)
+	if (state !== PETRA.BaseManager.STATE_CAPTURED || this.Config.difficulty < PETRA.DIFFICULTY_MEDIUM)
 		this.neededDefenders = 0;
 	else
 		this.neededDefenders = 3 + 2 * (this.Config.difficulty - 3);
@@ -95,7 +113,7 @@ PETRA.BaseManager.prototype.setAnchor = function(gameState, anchorEntity)
 		this.anchor = anchorEntity;
 		this.anchorId = anchorEntity.id();
 		this.anchor.setMetadata(PlayerID, "baseAnchor", true);
-		gameState.ai.HQ.resetBaseCache();
+		this.basesManager.resetBaseCache();
 	}
 	anchorEntity.setMetadata(PlayerID, "base", this.ID);
 	this.buildings.updateEnt(anchorEntity);
@@ -109,7 +127,7 @@ PETRA.BaseManager.prototype.anchorLost = function(gameState, ent)
 	this.anchor = undefined;
 	this.anchorId = undefined;
 	this.neededDefenders = 0;
-	gameState.ai.HQ.resetBaseCache();
+	this.basesManager.resetBaseCache();
 };
 
 /** Set a building of an anchorless base */
@@ -121,7 +139,7 @@ PETRA.BaseManager.prototype.setAnchorlessEntity = function(gameState, ent)
 			API3.warn("Error: Petra base " + this.ID + " has been assigned " + ent.templateName() + " as origin.");
 		this.accessIndex = PETRA.getLandAccess(gameState, ent);
 	}
-	else if (this.accessIndex != PETRA.getLandAccess(gameState, ent))
+	else if (this.accessIndex !== PETRA.getLandAccess(gameState, ent))
 		API3.warn(" Error: Petra base " + this.ID + " with access " + this.accessIndex +
 		          " has been assigned " + ent.templateName() + " with access" + PETRA.getLandAccess(gameState, ent));
 
@@ -148,7 +166,7 @@ PETRA.BaseManager.prototype.assignResourceToDropsite = function(gameState, drops
 	let dropsiteId = dropsite.id();
 	this.dropsites[dropsiteId] = true;
 
-	if (this.ID == gameState.ai.HQ.baseManagers[0].ID)
+	if (this.ID == this.basesManager.baselessBase().ID)
 		accessIndex = PETRA.getLandAccess(gameState, dropsite);
 
 	let maxDistResourceSquare = this.maxDistResourceSquare;
@@ -215,6 +233,18 @@ PETRA.BaseManager.prototype.assignResourceToDropsite = function(gameState, drops
 	});
 };
 
+PETRA.BaseManager.prototype.removeFromAssignedDropsite = function(ent)
+{
+	for (const type in this.dropsiteSupplies)
+		for (const proxim in this.dropsiteSupplies[type])
+		{
+			const resourcesList = this.dropsiteSupplies[type][proxim];
+			for (let i = 0; i < resourcesList.length; ++i)
+				if (resourcesList[i].id === ent.id())
+					resourcesList.splice(i--, 1);
+		}
+};
+
 // completely remove the dropsite resources from our list.
 PETRA.BaseManager.prototype.removeDropsite = function(gameState, ent)
 {
@@ -357,27 +387,18 @@ PETRA.BaseManager.prototype.findBestDropsiteLocation = function(gameState, resou
 	return { "quality": bestVal, "pos": [x, z] };
 };
 
-PETRA.BaseManager.prototype.getResourceLevel = function(gameState, type, nearbyOnly = false)
+PETRA.BaseManager.prototype.getResourceLevel = function(gameState, type, distances = ["nearby", "medium", "faraway"])
 {
 	let count = 0;
 	let check = {};
-	for (let supply of this.dropsiteSupplies[type].nearby)
-	{
-		if (check[supply.id])    // avoid double counting as same resource can appear several time
-			continue;
-		check[supply.id] = true;
-		count += supply.ent.resourceSupplyAmount();
-	}
-	if (nearbyOnly)
-		return count;
-
-	for (let supply of this.dropsiteSupplies[type].medium)
-	{
-		if (check[supply.id])
-			continue;
-		check[supply.id] = true;
-		count += 0.6*supply.ent.resourceSupplyAmount();
-	}
+	for (const proxim of distances)
+		for (const supply of this.dropsiteSupplies[type][proxim])
+		{
+			if (check[supply.id])    // avoid double counting as same resource can appear several time
+				continue;
+			check[supply.id] = true;
+			count += supply.ent.resourceSupplyAmount();
+		}
 	return count;
 };
 
@@ -388,9 +409,12 @@ PETRA.BaseManager.prototype.checkResourceLevels = function(gameState, queues)
 	{
 		if (type == "food")
 		{
+			const prox = ["nearby"];
+			if (gameState.currentPhase() < 2)
+				prox.push("medium");
 			if (gameState.ai.HQ.canBuild(gameState, "structures/{civ}/field"))	// let's see if we need to add new farms.
 			{
-				let count = this.getResourceLevel(gameState, type, gameState.currentPhase() > 1);  // animals are not accounted
+				const count = this.getResourceLevel(gameState, type, prox);  // animals are not accounted
 				let numFarms = gameState.getOwnStructures().filter(API3.Filters.byClass("Field")).length;  // including foundations
 				let numQueue = queues.field.countQueuedUnits();
 
@@ -420,7 +444,7 @@ PETRA.BaseManager.prototype.checkResourceLevels = function(gameState, queues)
 			if (!gameState.getOwnEntitiesByClass("Corral", true).hasEntities() &&
 			    !queues.corral.hasQueuedUnits() && gameState.ai.HQ.canBuild(gameState, "structures/{civ}/corral"))
 			{
-				let count = this.getResourceLevel(gameState, type, gameState.currentPhase() > 1);  // animals are not accounted
+				const count = this.getResourceLevel(gameState, type, prox);  // animals are not accounted
 				if (count < 900)
 				{
 					queues.corral.addPlan(new PETRA.ConstructionPlan(gameState, "structures/{civ}/corral", { "favoredBase": this.ID }));
@@ -497,14 +521,14 @@ PETRA.BaseManager.prototype.addGatherRates = function(gameState, currentRates)
 		});
 		if (res == "food")
 		{
-			this.workersBySubrole(gameState, "hunter").forEach(ent => {
+			this.workersBySubrole(gameState, PETRA.Worker.SUBROLE_HUNTER).forEach(ent => {
 				if (ent.isIdle() || !ent.position())
 					return;
 				let gRate = ent.currentGatherRate();
 				if (gRate)
 					currentRates[res] += Math.log(1+gRate)/1.1;
 			});
-			this.workersBySubrole(gameState, "fisher").forEach(ent => {
+			this.workersBySubrole(gameState, PETRA.Worker.SUBROLE_FISHER).forEach(ent => {
 				if (ent.isIdle() || !ent.position())
 					return;
 				let gRate = ent.currentGatherRate();
@@ -523,6 +547,8 @@ PETRA.BaseManager.prototype.assignRolelessUnits = function(gameState, roleless)
 	for (let ent of roleless)
 	{
 		if (ent.hasClasses(["Worker", "CitizenSoldier", "FishingBoat"]))
+			ent.setMetadata(PlayerID, "role", PETRA.Worker.ROLE_WORKER);
+		else if (ent.hasClass("Support") && ent.hasClass("Elephant"))
 			ent.setMetadata(PlayerID, "role", "worker");
 	}
 };
@@ -559,9 +585,9 @@ PETRA.BaseManager.prototype.setWorkersIdleByPriority = function(gameState)
 			if (lastFailed && gameState.ai.elapsedTime - lastFailed < 20)
 				continue;
 			// Ensure that the most wanted resource is not exhausted
-			if (moreNeed.type != "food" && gameState.ai.HQ.isResourceExhausted(moreNeed.type))
+			if (moreNeed.type != "food" && this.basesManager.isResourceExhausted(moreNeed.type))
 			{
-				if (lessNeed.type != "food" && gameState.ai.HQ.isResourceExhausted(lessNeed.type))
+				if (lessNeed.type != "food" && this.basesManager.isResourceExhausted(lessNeed.type))
 					continue;
 
 				// And if so, move the gatherer to the less wanted one.
@@ -573,7 +599,7 @@ PETRA.BaseManager.prototype.setWorkersIdleByPriority = function(gameState)
 			// If we assume a mean rate of 0.5 per gatherer, this diff should be > 1
 			// but we require a bit more to avoid too frequent changes
 			if (scale*moreNeed.wanted - moreNeed.current - scale*lessNeed.wanted + lessNeed.current > 1.5 ||
-			    lessNeed.type != "food" && gameState.ai.HQ.isResourceExhausted(lessNeed.type))
+			    lessNeed.type != "food" && this.basesManager.isResourceExhausted(lessNeed.type))
 			{
 				nb = this.switchGatherer(gameState, lessNeed.type, moreNeed.type, nb);
 				if (nb == 0)
@@ -609,7 +635,7 @@ PETRA.BaseManager.prototype.switchGatherer = function(gameState, from, to, numbe
 		--num;
 		ent.stopMoving();
 		ent.setMetadata(PlayerID, "gather-type", to);
-		gameState.ai.HQ.AddTCResGatherer(to);
+		this.basesManager.AddTCResGatherer(to);
 	}
 	return num;
 };
@@ -619,7 +645,7 @@ PETRA.BaseManager.prototype.reassignIdleWorkers = function(gameState, idleWorker
 	// Search for idle workers, and tell them to gather resources based on demand
 	if (!idleWorkers)
 	{
-		let filter = API3.Filters.byMetadata(PlayerID, "subrole", "idle");
+		const filter = API3.Filters.byMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_IDLE);
 		idleWorkers = gameState.updatingCollection("idle-workers-base-" + this.ID, filter, this.workers).values();
 	}
 
@@ -628,6 +654,12 @@ PETRA.BaseManager.prototype.reassignIdleWorkers = function(gameState, idleWorker
 		// Check that the worker isn't garrisoned
 		if (!ent.position())
 			continue;
+		// Support elephant can only be builders
+		if (ent.hasClass("Support") && ent.hasClass("Elephant"))
+		{
+			ent.setMetadata(PlayerID, "subrole", "idle");
+			continue;
+		}
 
 		if (ent.hasClass("Worker"))
 		{
@@ -645,19 +677,19 @@ PETRA.BaseManager.prototype.reassignIdleWorkers = function(gameState, idleWorker
 					let lastFailed = gameState.ai.HQ.lastFailedGather[needed.type];
 					if (lastFailed && gameState.ai.elapsedTime - lastFailed < 20)
 						continue;
-					if (needed.type != "food" && gameState.ai.HQ.isResourceExhausted(needed.type))
+					if (needed.type != "food" && this.basesManager.isResourceExhausted(needed.type))
 						continue;
-					ent.setMetadata(PlayerID, "subrole", "gatherer");
+					ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_GATHERER);
 					ent.setMetadata(PlayerID, "gather-type", needed.type);
-					gameState.ai.HQ.AddTCResGatherer(needed.type);
+					this.basesManager.AddTCResGatherer(needed.type);
 					break;
 				}
 			}
 		}
 		else if (PETRA.isFastMoving(ent) && ent.canGather("food") && ent.canAttackClass("Animal"))
-			ent.setMetadata(PlayerID, "subrole", "hunter");
+			ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_HUNTER);
 		else if (ent.hasClass("FishingBoat"))
-			ent.setMetadata(PlayerID, "subrole", "fisher");
+			ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_FISHER);
 	}
 };
 
@@ -668,7 +700,7 @@ PETRA.BaseManager.prototype.workersBySubrole = function(gameState, subrole)
 
 PETRA.BaseManager.prototype.gatherersByType = function(gameState, type)
 {
-	return gameState.updatingCollection("workers-gathering-" + type +"-base-" + this.ID, API3.Filters.byMetadata(PlayerID, "gather-type", type), this.workersBySubrole(gameState, "gatherer"));
+	return gameState.updatingCollection("workers-gathering-" + type +"-base-" + this.ID, API3.Filters.byMetadata(PlayerID, "gather-type", type), this.workersBySubrole(gameState, PETRA.Worker.SUBROLE_GATHERER));
 };
 
 /**
@@ -689,13 +721,13 @@ PETRA.BaseManager.prototype.pickBuilders = function(gameState, workers, number)
 	availableWorkers.sort((a, b) => {
 		let vala = 0;
 		let valb = 0;
-		if (a.getMetadata(PlayerID, "subrole") == "builder")
+		if (a.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_BUILDER)
 			vala = 100;
-		if (b.getMetadata(PlayerID, "subrole") == "builder")
+		if (b.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_BUILDER)
 			valb = 100;
-		if (a.getMetadata(PlayerID, "subrole") == "idle")
+		if (a.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_IDLE)
 			vala = -50;
-		if (b.getMetadata(PlayerID, "subrole") == "idle")
+		if (b.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_IDLE)
 			valb = -50;
 		if (a.getMetadata(PlayerID, "plan") === undefined)
 			vala = -20;
@@ -707,7 +739,7 @@ PETRA.BaseManager.prototype.pickBuilders = function(gameState, workers, number)
 	for (let i = 0; i < needed; ++i)
 	{
 		availableWorkers[i].stopMoving();
-		availableWorkers[i].setMetadata(PlayerID, "subrole", "idle");
+		availableWorkers[i].setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_IDLE);
 		workers.addEnt(availableWorkers[i]);
 	}
 	return;
@@ -729,7 +761,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 		return;
 
 	let workers = this.workers.filter(ent => ent.isBuilder());
-	let builderWorkers = this.workersBySubrole(gameState, "builder");
+	const builderWorkers = this.workersBySubrole(gameState, PETRA.Worker.SUBROLE_BUILDER);
 	let idleBuilderWorkers = builderWorkers.filter(API3.Filters.isIdle());
 
 	// if we're constructing and we have the foundations to our base anchor, only try building that.
@@ -749,13 +781,13 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 
 	if (workers.length < 3)
 	{
-		let fromOtherBase = gameState.ai.HQ.bulkPickWorkers(gameState, this, 2);
+		const fromOtherBase = this.basesManager.bulkPickWorkers(gameState, this, 2);
 		if (fromOtherBase)
 		{
 			let baseID = this.ID;
 			fromOtherBase.forEach(worker => {
 				worker.setMetadata(PlayerID, "base", baseID);
-				worker.setMetadata(PlayerID, "subrole", "builder");
+				worker.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_BUILDER);
 				workers.updateEnt(worker);
 				builderWorkers.updateEnt(worker);
 				idleBuilderWorkers.updateEnt(worker);
@@ -816,8 +848,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 			maxTotalBuilders = Math.max(maxTotalBuilders, 15);
 		}
 
-		// if no base yet, everybody should build
-		if (gameState.ai.HQ.numActiveBases() == 0)
+		if (!this.basesManager.hasActiveBase())
 		{
 			targetNB = workers.length;
 			maxTotalBuilders = targetNB;
@@ -838,7 +869,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 		if (assigned >= targetNB || builderTot >= maxTotalBuilders)
 			continue;
 		let nonBuilderWorkers = workers.filter(function(ent) {
-			if (ent.getMetadata(PlayerID, "subrole") == "builder")
+			if (ent.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_BUILDER)
 				return false;
 			if (!ent.position())
 				return false;
@@ -851,10 +882,15 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 		let time = target.buildTime();
 		nonBuilderWorkers.sort((workerA, workerB) => {
 			let coeffA = API3.SquareVectorDistance(target.position(), workerA.position());
-			if (workerA.getMetadata(PlayerID, "gather-type") == "food")
+			// elephant moves slowly, so when far away they are only useful if build time is long
+			if (workerA.hasClass("Elephant"))
+				coeffA *= 0.5 * (1 + Math.sqrt(coeffA)/5/time);
+			else if (workerA.getMetadata(PlayerID, "gather-type") == "food")
 				coeffA *= 3;
 			let coeffB = API3.SquareVectorDistance(target.position(), workerB.position());
-			if (workerB.getMetadata(PlayerID, "gather-type") == "food")
+			if (workerB.hasClass("Elephant"))
+				coeffB *= 0.5 * (1 + Math.sqrt(coeffB)/5/time);
+			else if (workerB.getMetadata(PlayerID, "gather-type") == "food")
 				coeffB *= 3;
 			return coeffA - coeffB;
 		});
@@ -866,7 +902,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 			++builderTot;
 			let ent = nonBuilderWorkers[current++];
 			ent.stopMoving();
-			ent.setMetadata(PlayerID, "subrole", "builder");
+			ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_BUILDER);
 			ent.setMetadata(PlayerID, "target-foundation", target.id());
 		}
 	}
@@ -921,7 +957,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 		if (assigned >= targetNB || builderTot >= maxTotalBuilders)
 			continue;
 		let nonBuilderWorkers = workers.filter(function(ent) {
-			if (ent.getMetadata(PlayerID, "subrole") == "builder")
+			if (ent.getMetadata(PlayerID, "subrole") === PETRA.Worker.SUBROLE_BUILDER)
 				return false;
 			if (!ent.position())
 				return false;
@@ -938,7 +974,7 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 			++assigned;
 			++builderTot;
 			ent.stopMoving();
-			ent.setMetadata(PlayerID, "subrole", "builder");
+			ent.setMetadata(PlayerID, "subrole", PETRA.Worker.SUBROLE_BUILDER);
 			ent.setMetadata(PlayerID, "target-foundation", target.id());
 		});
 	}
@@ -947,11 +983,11 @@ PETRA.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 /** Return false when the base is not active (no workers on it) */
 PETRA.BaseManager.prototype.update = function(gameState, queues, events)
 {
-	if (this.ID == gameState.ai.HQ.baseManagers[0].ID)	// base for unaffected units
+	if (this.ID == this.basesManager.baselessBase().ID)
 	{
 		// if some active base, reassigns the workers/buildings
 		// otherwise look for anything useful to do, i.e. treasures to gather
-		if (gameState.ai.HQ.numActiveBases() > 0)
+		if (this.basesManager.hasActiveBase())
 		{
 			for (let ent of this.units.values())
 			{
@@ -965,7 +1001,7 @@ PETRA.BaseManager.prototype.update = function(gameState, queues, events)
 				if (!bestBase)
 				{
 					if (ent.hasClass("Dock"))
-						API3.warn("Petra: dock in baseManager[0]. It may be useful to do an anchorless base for " + ent.templateName());
+						API3.warn("Petra: dock in 'noBase' baseManager. It may be useful to do an anchorless base for " + ent.templateName());
 					continue;
 				}
 				if (ent.resourceDropsiteTypes())
@@ -1056,7 +1092,7 @@ PETRA.BaseManager.prototype.update = function(gameState, queues, events)
 				if (API3.SquareVectorDistance(cc.position(), this.anchor.position()) > 8000)
 					continue;
 				this.anchor.destroy();
-				gameState.ai.HQ.resetBaseCache();
+				this.basesManager.resetBaseCache();
 				break;
 			}
 		}
@@ -1080,6 +1116,21 @@ PETRA.BaseManager.prototype.update = function(gameState, queues, events)
 	return true;
 };
 
+PETRA.BaseManager.prototype.AddTCGatherer = function(supplyID)
+{
+	return this.basesManager.AddTCGatherer(supplyID);
+};
+
+PETRA.BaseManager.prototype.RemoveTCGatherer = function(supplyID)
+{
+	this.basesManager.RemoveTCGatherer(supplyID);
+};
+
+PETRA.BaseManager.prototype.GetTCGatherer = function(supplyID)
+{
+	return this.basesManager.GetTCGatherer(supplyID);
+};
+
 PETRA.BaseManager.prototype.Serialize = function()
 {
 	return {
