@@ -69,26 +69,17 @@ PETRA.DefenseManager.prototype.makeIntoArmy = function(gameState, entityID, type
 {
 	if (type == "default")
 	{
-		// Try to add it to an existing army.
 		for (let army of this.armies)
 			if (army.getType() == type && army.addFoe(gameState, entityID))
-				return;	// over
+				return;
 	}
 
-	// Create a new army for it.
-	let army = new PETRA.DefenseArmy(gameState, [entityID], type);
-
-	this.armies.push(army);
+	this.armies.push(new PETRA.DefenseArmy(gameState, [entityID], type));
 };
 
 PETRA.DefenseManager.prototype.getArmy = function(partOfArmy)
 {
-	// Find the army corresponding to this ID partOfArmy.
-	for (let army of this.armies)
-		if (army.ID == partOfArmy)
-			return army;
-
-	return undefined;
+	return this.armies.find(army => army.ID == partOfArmy);
 };
 
 PETRA.DefenseManager.prototype.isDangerous = function(gameState, entity)
@@ -259,7 +250,7 @@ PETRA.DefenseManager.prototype.checkEnemyUnits = function(gameState)
 			this.makeIntoArmy(gameState, ent.id());
 	}
 
-	if (i != 0 || this.armies.length > 1 || gameState.ai.HQ.numActiveBases() == 0)
+	if (i != 0 || this.armies.length > 1 || !gameState.ai.HQ.hasActiveBase())
 		return;
 	// Look for possible gaia buildings inside our territory (may happen when enemy resign or after structure decay)
 	// and attack it only if useful (and capturable) or dangereous.
@@ -438,7 +429,8 @@ PETRA.DefenseManager.prototype.assignDefenders = function(gameState)
 		if (ent.getMetadata(PlayerID, "plan") !== undefined && ent.getMetadata(PlayerID, "plan") != -1)
 		{
 			let subrole = ent.getMetadata(PlayerID, "subrole");
-			if (subrole && (subrole == "completing" || subrole == "walking" || subrole == "attacking"))
+			if (subrole &&
+				(subrole === PETRA.Worker.SUBROLE_COMPLETING || subrole === PETRA.Worker.SUBROLE_WALKING || subrole === PETRA.Worker.SUBROLE_ATTACKING))
 				return;
 		}
 		potentialDefenders.push(ent.id());
@@ -597,7 +589,7 @@ PETRA.DefenseManager.prototype.checkEvents = function(gameState, events)
 		{
 			let base = gameState.ai.HQ.getBaseByID(target.getMetadata(PlayerID, "base"));
 			if (this.territoryMap.isBlinking(target.position()) && !gameState.ai.HQ.isDefendable(target) ||
-			    !base || gameState.ai.HQ.baseManagers.every(b => !b.anchor || b.accessIndex != base.accessIndex))
+			    !base || gameState.ai.HQ.baseManagers().every(b => !b.anchor || b.accessIndex != base.accessIndex))
 			{
 				let capture = target.capturePoints();
 				if (!capture)
@@ -615,7 +607,7 @@ PETRA.DefenseManager.prototype.checkEvents = function(gameState, events)
 		if (plan !== undefined && plan >= 0)
 		{
 			let attack = gameState.ai.HQ.attackManager.getPlan(plan);
-			if (attack && attack.state != "unexecuted")
+			if (attack && attack.state != PETRA.AttackPlan.STATE_UNEXECUTED)
 				continue;
 		}
 
@@ -761,7 +753,7 @@ PETRA.DefenseManager.prototype.garrisonUnitsInside = function(gameState, target,
 	let access = PETRA.getLandAccess(gameState, target);
 	let garrisonManager = gameState.ai.HQ.garrisonManager;
 	let garrisonArrowClasses = target.getGarrisonArrowClasses();
-	let typeGarrison = data.type || "protection";
+	const typeGarrison = data.type || PETRA.GarrisonManager.TYPE_PROTECTION;
 	let allowMelee = gameState.ai.HQ.garrisonManager.allowMelee(target);
 	if (allowMelee === undefined)
 	{
@@ -776,7 +768,7 @@ PETRA.DefenseManager.prototype.garrisonUnitsInside = function(gameState, target,
 			return false;
 		if (!ent.hasClasses(garrisonArrowClasses))
 			return false;
-		if (typeGarrison != "decay" && !allowMelee && ent.attackTypes().indexOf("Melee") != -1)
+		if (typeGarrison !== PETRA.GarrisonManager.TYPE_DECAY && !allowMelee && ent.attackTypes().indexOf("Melee") != -1)
 			return false;
 		if (ent.getMetadata(PlayerID, "transport") !== undefined)
 			return false;
@@ -787,7 +779,8 @@ PETRA.DefenseManager.prototype.garrisonUnitsInside = function(gameState, target,
 		{
 			let subrole = ent.getMetadata(PlayerID, "subrole");
 			// When structure decaying (usually because we've just captured it in enemy territory), also allow units from an attack plan.
-			if (typeGarrison != "decay" && subrole && (subrole == "completing" || subrole == "walking" || subrole == "attacking"))
+			if (typeGarrison !== PETRA.GarrisonManager.TYPE_DECAY && subrole &&
+				(subrole === PETRA.Worker.SUBROLE_COMPLETING || subrole === PETRA.Worker.SUBROLE_WALKING || subrole === PETRA.Worker.SUBROLE_ATTACKING))
 				return false;
 		}
 		if (PETRA.getLandAccess(gameState, ent) != access)
@@ -841,7 +834,7 @@ PETRA.DefenseManager.prototype.garrisonSiegeUnit = function(gameState, unit)
 		nearest = ent;
 	}
 	if (nearest)
-		garrisonManager.garrison(gameState, unit, nearest, "protection");
+		garrisonManager.garrison(gameState, unit, nearest, PETRA.GarrisonManager.TYPE_PROTECTION);
 	return nearest !== undefined;
 };
 
@@ -882,13 +875,13 @@ PETRA.DefenseManager.prototype.garrisonAttackedUnit = function(gameState, unit,
 
 	if (!emergency)
 	{
-		garrisonManager.garrison(gameState, unit, nearest, "protection");
+		garrisonManager.garrison(gameState, unit, nearest, PETRA.GarrisonManager.TYPE_PROTECTION);
 		return true;
 	}
 	if (garrisonManager.numberOfGarrisonedSlots(nearest) >= nearest.garrisonMax()) // make room for this ent
 		nearest.unload(nearest.garrisoned()[0]);
 
-	garrisonManager.garrison(gameState, unit, nearest, nearest.buffHeal() ? "protection" : "emergency");
+	garrisonManager.garrison(gameState, unit, nearest, nearest.buffHeal() ? PETRA.GarrisonManager.TYPE_PROTECTION : PETRA.GarrisonManager.TYPE_EMERGENCY);
 	return true;
 };
 
