@@ -79,7 +79,7 @@ PETRA.ResearchManager.prototype.researchWantedTechs = function(gameState, techs)
 {
 	let phase1 = gameState.currentPhase() === 1;
 	let available = phase1 ? gameState.ai.queueManager.getAvailableResources(gameState) : null;
-	let numWorkers = phase1 ? gameState.getOwnEntitiesByRole("worker", true).length : 0;
+	const numWorkers = phase1 ? gameState.getOwnEntitiesByRole(PETRA.Worker.ROLE_WORKER, true).length : 0;
 	for (let tech of techs)
 	{
 		if (tech[0].indexOf("unlock_champion") == 0)
@@ -105,7 +105,7 @@ PETRA.ResearchManager.prototype.researchWantedTechs = function(gameState, techs)
 				return { "name": tech[0], "increasePriority": this.CostSum(template.cost) < 400 };
 			else if (template.modifications[i].value === "ResourceGatherer/Rates/food.fruit")
 				return { "name": tech[0], "increasePriority": this.CostSum(template.cost) < 400 };
-			else if (template.modifications[i].value === "ResourceGatherer/Rates/food.grain")
+			else if (template.modifications[i].value === "ResourceGatherer/Rates/food.grain" || template.modifications[i].value === "ResourceGatherer/Rates/food.rice")
 				return { "name": tech[0], "increasePriority": false };
 			else if (template.modifications[i].value === "ResourceGatherer/Rates/wood.tree")
 				return { "name": tech[0], "increasePriority": this.CostSum(template.cost) < 400 };
@@ -123,7 +123,7 @@ PETRA.ResearchManager.prototype.researchPreferredTechs = function(gameState, tec
 {
 	let phase2 = gameState.currentPhase() === 2;
 	let available = phase2 ? gameState.ai.queueManager.getAvailableResources(gameState) : null;
-	let numWorkers = phase2 ? gameState.getOwnEntitiesByRole("worker", true).length : 0;
+	const numWorkers = phase2 ? gameState.getOwnEntitiesByRole(PETRA.Worker.ROLE_WORKER, true).length : 0;
 	for (let tech of techs)
 	{
 		if (!tech[1]._template.modifications)
@@ -210,7 +210,7 @@ PETRA.ResearchManager.prototype.update = function(gameState, queues)
 			continue;
 		}
 		if (template.modifications && template.modifications.length === 1 &&
-			template.modifications[0].value === "Player/sharedLos" &&
+			this.Config.unusedNoAllyTechs.includes(template.modifications[0].value) &&
 			!gameState.hasAllies())
 		{
 			techs.splice(i--, 1);
