@@ -57,10 +57,14 @@ Attack.prototype.Schema =
 			"</Damage>" +
 			"<MaxRange>44.0</MaxRange>" +
 			"<MinRange>20.0</MinRange>" +
-			"<ElevationBonus>15.0</ElevationBonus>" +
+			"<Origin>" +
+				"<X>0</X>" +
+				"<Y>10.0</Y>" +
+				"<Z>0</Z>" +
+			"</Origin>" +
 			"<PrepareTime>800</PrepareTime>" +
 			"<RepeatTime>1600</RepeatTime>" +
-			"<Delay>1000</Delay>" +
+			"<EffectDelay>1000</EffectDelay>" +
 			"<Bonuses>" +
 				"<Bonus1>" +
 					"<Classes>Cavalry</Classes>" +
@@ -115,7 +119,19 @@ Attack.prototype.Schema =
 					"<element name='MinRange' a:help='Minimum attack range (in metres). Defaults to 0.'><ref name='nonNegativeDecimal'/></element>" +
 				"</optional>" +
 				"<optional>"+
-					"<element name='ElevationBonus' a:help='The offset height from which the attack occurs, relative to the entity position. Defaults to 0.'><ref name='nonNegativeDecimal'/></element>" +
+					"<element name='Origin' a:help='The offset from which the attack occurs, relative to the entity position. Defaults to {0,0,0}.'>" +
+						"<interleave>" +
+							"<element name='X'>" +
+								"<ref name='nonNegativeDecimal'/>" +
+							"</element>" +
+							"<element name='Y'>" +
+								"<ref name='nonNegativeDecimal'/>" +
+							"</element>" +
+							"<element name='Z'>" +
+								"<ref name='nonNegativeDecimal'/>" +
+							"</element>" +
+						"</interleave>" +
+					"</element>" +
 				"</optional>" +
 				"<optional>" +
 					"<element name='RangeOverlay'>" +
@@ -135,7 +151,7 @@ Attack.prototype.Schema =
 					"<data type='positiveInteger'/>" +
 				"</element>" +
 				"<optional>" +
-					"<element name='Delay' a:help='Delay of applying the effects in milliseconds after the attack has landed. Defaults to 0.'><ref name='nonNegativeDecimal'/></element>" +
+					"<element name='EffectDelay' a:help='Delay of applying the effects, in milliseconds after the attack has landed. Defaults to 0.'><ref name='nonNegativeDecimal'/></element>" +
 				"</optional>" +
 				"<optional>" +
 					"<element name='Splash'>" +
@@ -438,10 +454,14 @@ Attack.prototype.GetRange = function(type)
 	let min = +(this.template[type].MinRange || 0);
 	min = ApplyValueModificationsToEntity("Attack/" + type + "/MinRange", min, this.entity);
 
-	let elevationBonus = +(this.template[type].ElevationBonus || 0);
-	elevationBonus = ApplyValueModificationsToEntity("Attack/" + type + "/ElevationBonus", elevationBonus, this.entity);
+	return { "max": max, "min": min };
+};
 
-	return { "max": max, "min": min, "elevationBonus": elevationBonus };
+Attack.prototype.GetAttackYOrigin = function(type)
+{
+	if (!this.template[type].Origin)
+		return 0;
+	return ApplyValueModificationsToEntity("Attack/" + type + "/Origin/Y", +this.template[type].Origin.Y, this.entity);
 };
 
 /**
@@ -459,7 +479,7 @@ Attack.prototype.StartAttacking = function(target, type, callerIID)
 	if (!this.CanAttack(target, [type]))
 		return false;
 
-	let cmpResistance = Engine.QueryInterface(target, IID_Resistance);
+	const cmpResistance = QueryMiragedInterface(target, IID_Resistance);
 	if (!cmpResistance || !cmpResistance.AddAttacker(this.entity))
 		return false;
 
@@ -504,7 +524,7 @@ Attack.prototype.StopAttacking = function(reason)
 	cmpTimer.CancelTimer(this.timer);
 	delete this.timer;
 
-	let cmpResistance = Engine.QueryInterface(this.target, IID_Resistance);
+	const cmpResistance = QueryMiragedInterface(this.target, IID_Resistance);
 	if (cmpResistance)
 		cmpResistance.RemoveAttacker(this.entity);
 
@@ -604,7 +624,7 @@ Attack.prototype.PerformAttack = function(type, target)
 		"target": target,
 	};
 
-	let delay = +(this.template[type].Delay || 0);
+	let delay = +(this.template[type].EffectDelay || 0);
 
 	if (this.template[type].Projectile)
 	{
@@ -719,28 +739,14 @@ Attack.prototype.PerformAttack = function(type, target)
  */
 Attack.prototype.IsTargetInRange = function(target, type)
 {
-	let range = this.GetRange(type);
-	if (type == "Ranged")
-	{
-		let cmpPositionTarget = Engine.QueryInterface(target, IID_Position);
-		if (!cmpPositionTarget || !cmpPositionTarget.IsInWorld())
-			return false;
-
-		let cmpPositionSelf = Engine.QueryInterface(this.entity, IID_Position);
-		if (!cmpPositionSelf || !cmpPositionSelf.IsInWorld())
-			return false;
-
-		let positionSelf = cmpPositionSelf.GetPosition();
-		let positionTarget = cmpPositionTarget.GetPosition();
-
-		let heightDifference = positionSelf.y + range.elevationBonus - positionTarget.y;
-		range.max = Math.sqrt(Math.square(range.max) + 2 * range.max * heightDifference);
-
-		if (range.max < 0)
-			return false;
-	}
-	let cmpObstructionManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ObstructionManager);
-	return cmpObstructionManager.IsInTargetRange(this.entity, target, range.min, range.max, false);
+	const range = this.GetRange(type);
+	return Engine.QueryInterface(SYSTEM_ENTITY, IID_ObstructionManager).IsInTargetParabolicRange(
+		this.entity,
+		target,
+		range.min,
+		range.max,
+		this.GetAttackYOrigin(type),
+		false);
 };
 
 Attack.prototype.OnValueModification = function(msg)
