@@ -220,7 +220,7 @@ BuildRestrictions.prototype.CheckPlacement = function()
 		result.message = markForTranslation("%(name)s cannot be built in %(territoryType)s territory. Valid territories: %(validTerritories)s");
 		result.translateParameters.push("territoryType");
 		result.translateParameters.push("validTerritories");
-		result.parameters.territoryType = { "context": "Territory type", "message": invalidTerritory };
+		result.parameters.territoryType = { "context": "Territory type", "_string": invalidTerritory };
 		// gui code will join this array to a string
 		result.parameters.validTerritories = { "context": "Territory type list", "list": this.GetTerritories() };
 		return result;	// Fail
