@@ -11,6 +11,12 @@ Player.prototype.Schema =
 			"</element>" +
 		"</interleave>" +
 	"</element>" +
+	"<element name='Formations' a:help='Space-separated list of formations this player can use.'>" +
+		"<attribute name='datatype'>" +
+			"<value>tokens</value>" +
+		"</attribute>" +
+		"<text/>" +
+	"</element>" +
 	"<element name='SharedLosTech' a:help='Allies will share los when this technology is researched. Leave empty to never share LOS.'>" +
 		"<text/>" +
 	"</element>" +
@@ -50,8 +56,6 @@ var panelEntityClasses = "Hero Relic";
 Player.prototype.Init = function()
 {
 	this.playerID = undefined;
-	this.name = undefined;	// Define defaults elsewhere (supporting other languages).
-	this.civ = undefined;
 	this.color = undefined;
 	this.diplomacyColor = undefined;
 	this.displayDiplomacyColor = false;
@@ -67,7 +71,7 @@ Player.prototype.Init = function()
 	this.state = "active"; // Game state. One of "active", "defeated", "won".
 	this.diplomacy = [];	// Array of diplomatic stances for this player with respect to other players (including gaia and self).
 	this.sharedDropsites = false;
-	this.formations = [];
+	this.formations = this.template.Formations._string.split(" ");
 	this.startCam = undefined;
 	this.controlAllUnits = false;
 	this.isAI = false;
@@ -112,34 +116,6 @@ Player.prototype.GetPlayerID = function()
 	return this.playerID;
 };
 
-Player.prototype.SetName = function(name)
-{
-	this.name = name;
-};
-
-Player.prototype.GetName = function()
-{
-	return this.name;
-};
-
-Player.prototype.SetCiv = function(civcode)
-{
-	let oldCiv = this.civ;
-	this.civ = civcode;
-	// Normally, the civ is only set once. But in Atlas, map designers can change civs at any time.
-	if (oldCiv && this.playerID && oldCiv != civcode)
-		Engine.BroadcastMessage(MT_CivChanged, {
-			"player": this.playerID,
-			"from": oldCiv,
-			"to": civcode
-		});
-};
-
-Player.prototype.GetCiv = function()
-{
-	return this.civ;
-};
-
 Player.prototype.SetColor = function(r, g, b)
 {
 	let colorInitialized = !!this.color;
@@ -390,6 +366,16 @@ Player.prototype.TrySubtractResources = function(amounts)
 	return true;
 };
 
+Player.prototype.RefundResources = function(amounts)
+{
+	const cmpStatisticsTracker = QueryPlayerIDInterface(this.playerID, IID_StatisticsTracker);
+	if (cmpStatisticsTracker)
+		for (const type in amounts)
+			cmpStatisticsTracker.IncreaseResourceUsedCounter(type, -amounts[type]);
+
+	this.AddResources(amounts);
+};
+
 Player.prototype.GetNextTradingGoods = function()
 {
 	let value = randFloat(0, 100);
@@ -446,6 +432,14 @@ Player.prototype.GetState = function()
 	return this.state;
 };
 
+/**
+ * @return {boolean} -
+ */
+Player.prototype.IsActive = function()
+{
+	return this.state === "active";
+};
+
 /**
  * @param {string} newState - Either "defeated" or "won".
  * @param {string|undefined} message - A string to be shown in chat, for example
@@ -498,18 +492,15 @@ Player.prototype.SetState = function(newState, message)
 			});
 	}
 
-	Engine.PostMessage(this.entity, won ? MT_PlayerWon : MT_PlayerDefeated, { "playerId": this.playerID });
-
 	if (message)
-	{
-		let cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
-		cmpGUIInterface.PushNotification({
+		Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface).PushNotification({
 			"type": won ? "won" : "defeat",
 			"players": [this.playerID],
 			"allies": [this.playerID],
 			"message": message
 		});
-	}
+
+	Engine.PostMessage(this.entity, won ? MT_PlayerWon : MT_PlayerDefeated, { "playerId": this.playerID });
 };
 
 Player.prototype.GetTeam = function()
@@ -763,9 +754,10 @@ Player.prototype.OnGlobalInitGame = function(msg)
 	// Replace the "{civ}" code with this civ ID.
 	let disabledTemplates = this.disabledTemplates;
 	this.disabledTemplates = {};
+	const civ = Engine.QueryInterface(this.entity, IID_Identity).GetCiv();
 	for (let template in disabledTemplates)
 		if (disabledTemplates[template])
-			this.disabledTemplates[template.replace(/\{civ\}/g, this.civ)] = true;
+			this.disabledTemplates[template.replace(/\{civ\}/g, civ)] = true;
 };
 
 /**
