@@ -75,8 +75,6 @@ ResourceGatherer.prototype.GiveResources = function(resources)
 {
 	for (let resource of resources)
 		this.carrying[resource.type] = +resource.amount;
-
-	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
 /**
@@ -284,8 +282,6 @@ ResourceGatherer.prototype.PerformGather = function(data, lateness)
 	if (cmpStatisticsTracker)
 		cmpStatisticsTracker.IncreaseResourceGatheredCounter(type.generic, status.amount, type.specific);
 
-	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
-
 	if (!this.CanCarryMore(type.generic))
 		this.StopGathering("InventoryFilled");
 	else if (status.exhausted)
@@ -399,17 +395,12 @@ ResourceGatherer.prototype.CommitResources = function(target)
 		return;
 
 	let change = cmpResourceDropsite.ReceiveResources(this.carrying, this.entity);
-	let changed = false;
 	for (let type in change)
 	{
 		this.carrying[type] -= change[type];
 		if (this.carrying[type] == 0)
 			delete this.carrying[type];
-		changed = true;
 	}
-
-	if (changed)
-		Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
 /**
@@ -420,16 +411,14 @@ ResourceGatherer.prototype.CommitResources = function(target)
 ResourceGatherer.prototype.DropResources = function()
 {
 	this.carrying = {};
-
-	Engine.PostMessage(this.entity, MT_ResourceCarryingChanged, { "to": this.GetCarryingStatus() });
 };
 
 /**
  * @return {string} - A generic resource type if we were tasked to gather.
  */
-ResourceGatherer.prototype.LastGatheredType = function()
+ResourceGatherer.prototype.GetTaskedResourceType = function()
 {
-	return this.lastGathered;
+	return this.taskedResourceType;
 };
 
 /**
@@ -438,14 +427,14 @@ ResourceGatherer.prototype.LastGatheredType = function()
 ResourceGatherer.prototype.AddToPlayerCounter = function(type)
 {
 	// We need to be removed from the player counter first.
-	if (this.lastGathered)
+	if (this.taskedResourceType)
 		return;
 
 	let cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
 	if (cmpPlayer)
 		cmpPlayer.AddResourceGatherer(type);
 
-	this.lastGathered = type;
+	this.taskedResourceType = type;
 };
 
 /**
@@ -453,7 +442,7 @@ ResourceGatherer.prototype.AddToPlayerCounter = function(type)
  */
 ResourceGatherer.prototype.RemoveFromPlayerCounter = function(playerid)
 {
-	if (!this.lastGathered)
+	if (!this.taskedResourceType)
 		return;
 
 	let cmpPlayer = playerid != undefined ?
@@ -461,9 +450,9 @@ ResourceGatherer.prototype.RemoveFromPlayerCounter = function(playerid)
 		QueryOwnerInterface(this.entity, IID_Player);
 
 	if (cmpPlayer)
-		cmpPlayer.RemoveResourceGatherer(this.lastGathered);
+		cmpPlayer.RemoveResourceGatherer(this.taskedResourceType);
 
-	delete this.lastGathered;
+	delete this.taskedResourceType;
 };
 
 /**
@@ -505,6 +494,12 @@ ResourceGatherer.prototype.OnOwnershipChanged = function(msg)
 		this.RemoveFromPlayerCounter(msg.from);
 		return;
 	}
+	if (this.lastGathered && msg.from !== INVALID_PLAYER)
+	{
+		const resource = this.taskedResourceType;
+		this.RemoveFromPlayerCounter(msg.from);
+		this.AddToPlayerCounter(resource);
+	}
 
 	this.RecalculateGatherRates();
 	this.RecalculateCapacities();
