@@ -345,9 +345,27 @@ UnitMotionFlying.prototype.GetSpeedMultiplier = function()
 	return this.speed / +this.template.MaxSpeed;
 };
 
+UnitMotionFlying.prototype.GetAcceleration = function()
+{
+	return +this.template.AccelRate;
+};
+
+UnitMotionFlying.prototype.SetAcceleration = function()
+{
+	// Acceleration is set by the template. Ignore.
+};
+
 UnitMotionFlying.prototype.GetPassabilityClassName = function()
 {
-	return this.template.PassabilityClass;
+	return this.passabilityClassName ? this.passabilityClassName : this.template.PassabilityClass;
+};
+
+UnitMotionFlying.prototype.SetPassabilityClassName = function(passClassName)
+{
+	this.passabilityClassName = passClassName;
+	const cmpPathfinder = Engine.QueryInterface(SYSTEM_ENTITY, IID_Pathfinder);
+	if (cmpPathfinder)
+		this.passabilityClass = cmpPathfinder.GetPassabilityClass(passClassName);
 };
 
 UnitMotionFlying.prototype.GetPassabilityClass = function()
