@@ -56,24 +56,8 @@ Upgrade.prototype.Schema =
 
 Upgrade.prototype.Init = function()
 {
-	this.upgrading = false;
-	this.completed = false;
 	this.elapsedTime = 0;
-	this.timer = undefined;
 	this.expendedResources = {};
-
-	this.upgradeTemplates = {};
-
-	for (let choice in this.template)
-	{
-		let cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
-		let name = this.template[choice].Entity;
-		if (cmpIdentity)
-			name = name.replace(/\{civ\}/g, cmpIdentity.GetCiv());
-		if (this.upgradeTemplates.name)
-			warn("Upgrade Component: entity " + this.entity + " has two upgrades to the same entity, only the last will be used.");
-		this.upgradeTemplates[name] = choice;
-	}
 };
 
 // This will also deal with the "OnDestroy" case.
@@ -83,7 +67,32 @@ Upgrade.prototype.OnOwnershipChanged = function(msg)
 		this.CancelUpgrade(msg.from);
 
 	if (msg.to != INVALID_PLAYER)
+	{
 		this.owner = msg.to;
+		this.DetermineUpgrades();
+	}
+};
+
+Upgrade.prototype.DetermineUpgrades = function()
+{
+	this.upgradeTemplates = {};
+
+	for (const choice in this.template)
+	{
+		const nativeCiv = Engine.QueryInterface(this.entity, IID_Identity).GetCiv();
+		const playerCiv = QueryPlayerIDInterface(this.owner, IID_Identity).GetCiv();
+		const name = this.template[choice].Entity.
+			replace(/\{native\}/g, nativeCiv).
+			replace(/\{civ\}/g, playerCiv);
+
+		if (!Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager).TemplateExists(name))
+			continue;
+
+		if (this.upgradeTemplates[name])
+			warn("Upgrade Component: entity " + this.entity + " has two upgrades to the same entity, only the last will be used.");
+
+		this.upgradeTemplates[name] = choice;
+	}
 };
 
 Upgrade.prototype.ChangeUpgradedEntityCount = function(amount)
@@ -128,22 +137,19 @@ Upgrade.prototype.GetUpgrades = function()
 {
 	let ret = [];
 
-	let cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
-
-	for (let option in this.template)
+	for (const option in this.upgradeTemplates)
 	{
-		let choice = this.template[option];
-		let templateName = cmpIdentity ? choice.Entity.replace(/\{civ\}/g, cmpIdentity.GetCiv()) : choice.Entity;
+		const choice = this.template[this.upgradeTemplates[option]];
 
 		let cost = {};
 		if (choice.Cost)
-			cost = this.GetResourceCosts(templateName);
+			cost = this.GetResourceCosts(option);
 		if (choice.Time)
-			cost.time = this.GetUpgradeTime(templateName);
+			cost.time = this.GetUpgradeTime(option);
 
 		let hasCost = choice.Cost || choice.Time;
 		ret.push({
-			"entity": templateName,
+			"entity": option,
 			"icon": choice.Icon || undefined,
 			"cost": hasCost ? cost : undefined,
 			"tooltip": choice.Tooltip || undefined,
@@ -161,7 +167,7 @@ Upgrade.prototype.CancelTimer = function()
 
 	let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
 	cmpTimer.CancelTimer(this.timer);
-	this.timer = undefined;
+	delete this.timer;
 };
 
 Upgrade.prototype.IsUpgrading = function()
@@ -289,7 +295,7 @@ Upgrade.prototype.CancelUpgrade = function(owner)
 			cmpVisual.SelectAnimation("idle", false, 1.0);
 	}
 
-	this.upgrading = false;
+	delete this.upgrading;
 	this.CancelTimer();
 	this.SetElapsedTime(0);
 };
