@@ -1,10 +1,3 @@
-/**
- * Message of the form { "player": number, "from": string, "to": string }
- * sent from Player component to warn other components when a player changed civs.
- * This should only happen in Atlas.
- */
-Engine.RegisterMessageType("CivChanged");
-
 /**
  * Message of the form { "player": number, "otherPlayer": number }
  * sent from Player component when diplomacy changed for one player or between two players.
