@@ -6,10 +6,10 @@ Engine.LoadComponentScript("interfaces/Barter.js");
 Engine.LoadComponentScript("interfaces/Builder.js");
 Engine.LoadComponentScript("interfaces/Capturable.js");
 Engine.LoadComponentScript("interfaces/CeasefireManager.js");
-Engine.LoadComponentScript("interfaces/Resistance.js");
 Engine.LoadComponentScript("interfaces/DeathDamage.js");
 Engine.LoadComponentScript("interfaces/EndGameManager.js");
 Engine.LoadComponentScript("interfaces/EntityLimits.js");
+Engine.LoadComponentScript("interfaces/Formation.js");
 Engine.LoadComponentScript("interfaces/Foundation.js");
 Engine.LoadComponentScript("interfaces/Garrisonable.js");
 Engine.LoadComponentScript("interfaces/GarrisonHolder.js");
@@ -24,12 +24,15 @@ Engine.LoadComponentScript("interfaces/Population.js");
 Engine.LoadComponentScript("interfaces/ProductionQueue.js");
 Engine.LoadComponentScript("interfaces/Promotion.js");
 Engine.LoadComponentScript("interfaces/Repairable.js");
+Engine.LoadComponentScript("interfaces/Researcher.js");
+Engine.LoadComponentScript("interfaces/Resistance.js");
 Engine.LoadComponentScript("interfaces/ResourceDropsite.js");
 Engine.LoadComponentScript("interfaces/ResourceGatherer.js");
 Engine.LoadComponentScript("interfaces/ResourceTrickle.js");
 Engine.LoadComponentScript("interfaces/ResourceSupply.js");
 Engine.LoadComponentScript("interfaces/TechnologyManager.js");
 Engine.LoadComponentScript("interfaces/Trader.js");
+Engine.LoadComponentScript("interfaces/Trainer.js");
 Engine.LoadComponentScript("interfaces/TurretHolder.js");
 Engine.LoadComponentScript("interfaces/Timer.js");
 Engine.LoadComponentScript("interfaces/Treasure.js");
@@ -97,8 +100,6 @@ AddMock(SYSTEM_ENTITY, IID_Timer, {
 });
 
 AddMock(100, IID_Player, {
-	"GetName": function() { return "Player 1"; },
-	"GetCiv": function() { return "gaia"; },
 	"GetColor": function() { return { "r": 1, "g": 1, "b": 1, "a": 1 }; },
 	"CanControlAllUnits": function() { return false; },
 	"GetPopulationCount": function() { return 10; },
@@ -125,6 +126,12 @@ AddMock(100, IID_Player, {
 	"HasSharedLos": function() { return false; }
 });
 
+AddMock(100, IID_Identity, {
+	"GetName": function() { return "Player 1"; },
+	"GetCiv": function() { return "gaia"; },
+	"GetRankTechName": function() { return undefined; }
+});
+
 AddMock(100, IID_EntityLimits, {
 	"GetLimits": function() { return { "Foo": 10 }; },
 	"GetCounts": function() { return { "Foo": 5 }; },
@@ -185,8 +192,6 @@ AddMock(100, IID_StatisticsTracker, {
 });
 
 AddMock(101, IID_Player, {
-	"GetName": function() { return "Player 2"; },
-	"GetCiv": function() { return "mace"; },
 	"GetColor": function() { return { "r": 1, "g": 0, "b": 0, "a": 1 }; },
 	"CanControlAllUnits": function() { return true; },
 	"GetPopulationCount": function() { return 40; },
@@ -213,6 +218,12 @@ AddMock(101, IID_Player, {
 	"HasSharedLos": function() { return false; }
 });
 
+AddMock(101, IID_Identity, {
+	"GetName": function() { return "Player 2"; },
+	"GetCiv": function() { return "mace"; },
+	"GetRankTechName": function() { return undefined; }
+});
+
 AddMock(101, IID_EntityLimits, {
 	"GetLimits": function() { return { "Bar": 20 }; },
 	"GetCounts": function() { return { "Bar": 0 }; },
@@ -308,7 +319,6 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			"matchEntityCounts": { "Bar": 0 },
 			"entityLimitChangers": { "Foo": {} },
 			"researchQueued": new Map(),
-			"researchStarted": new Set(),
 			"researchedTechs": new Set(),
 			"classCounts": {},
 			"typeCountsByClass": {},
@@ -359,7 +369,6 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			"matchEntityCounts": { "Foo": 0 },
 			"entityLimitChangers": { "Bar": {} },
 			"researchQueued": new Map(),
-			"researchStarted": new Set(),
 			"researchedTechs": new Set(),
 			"classCounts": {},
 			"typeCountsByClass": {},
@@ -420,7 +429,6 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			"matchEntityCounts": { "Bar": 0 },
 			"entityLimitChangers": { "Foo": {} },
 			"researchQueued": new Map(),
-			"researchStarted": new Set(),
 			"researchedTechs": new Set(),
 			"classCounts": {},
 			"typeCountsByClass": {},
@@ -494,7 +502,6 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			"matchEntityCounts": { "Foo": 0 },
 			"entityLimitChangers": { "Bar": {} },
 			"researchQueued": new Map(),
-			"researchStarted": new Set(),
 			"researchedTechs": new Set(),
 			"classCounts": {},
 			"typeCountsByClass": {},
@@ -566,8 +573,7 @@ AddMock(10, IID_Identity, {
 	"HasClass": function() { return true; },
 	"IsUndeletable": function() { return false; },
 	"IsControllable": function() { return true; },
-	"HasSomeFormation": function() { return false; },
-	"GetFormationsList": function() { return []; },
+	"GetRankTechName": function() { return undefined; }
 });
 
 AddMock(10, IID_Position, {
@@ -594,11 +600,10 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetEntityState(-1, 10), {
 	"template": "example",
 	"identity": {
 		"rank": "foo",
+		"rankTechName": undefined,
 		"classes": ["class1", "class2"],
 		"selectionGroupName": "Selection Group Name",
 		"canDelete": true,
-		"hasSomeFormation": false,
-		"formations": [],
 		"controllable": true,
 	},
 	"position": { "x": 1, "y": 2, "z": 3 },
