@@ -14,6 +14,7 @@ Engine.LoadComponentScript("interfaces/Pack.js");
 Engine.LoadComponentScript("interfaces/ResourceSupply.js");
 Engine.LoadComponentScript("interfaces/ResourceGatherer.js");
 Engine.LoadComponentScript("interfaces/Timer.js");
+Engine.LoadComponentScript("interfaces/Turretable.js");
 Engine.LoadComponentScript("interfaces/UnitAI.js");
 Engine.LoadComponentScript("Formation.js");
 Engine.LoadComponentScript("UnitAI.js");
@@ -94,6 +95,7 @@ TestTargetEntityRenaming(
 			"MoveToTargetRange": () => true,
 			"GetRunMultiplier": () => 1,
 			"SetSpeedMultiplier": () => {},
+			"GetAcceleration": () => 1,
 			"StopMoving": () => {}
 		});
 
@@ -168,6 +170,7 @@ function TestFormationExiting(mode)
 
 	AddMock(unit, IID_UnitMotion, {
 		"GetWalkSpeed": () => 1,
+		"GetAcceleration": () => 1,
 		"MoveToFormationOffset": (target, x, z) => {},
 		"MoveToTargetRange": (target, min, max) => true,
 		"SetMemberOfFormation": () => {},
@@ -214,7 +217,6 @@ function TestFormationExiting(mode)
 		});
 
 	let controllerFormation = ConstructComponent(controller, "Formation", {
-		"FormationName": "Line Closed",
 		"FormationShape": "square",
 		"ShiftRows": "false",
 		"SortingClasses": "",
@@ -231,6 +233,7 @@ function TestFormationExiting(mode)
 
 	AddMock(controller, IID_Position, {
 		"JumpTo": function(x, z) { this.x = x; this.z = z; },
+		"TurnTo": function() {},
 		"GetTurretParent": function() { return INVALID_ENTITY; },
 		"GetPosition": function() { return new Vector3D(this.x, 0, this.z); },
 		"GetPosition2D": function() { return new Vector2D(this.x, this.z); },
@@ -243,12 +246,19 @@ function TestFormationExiting(mode)
 		"GetWalkSpeed": () => 1,
 		"StopMoving": () => {},
 		"SetSpeedMultiplier": () => {},
+		"SetAcceleration": (accel) => {},
+		"SetPassabilityClassName": (name) => {},
 		"MoveToPointRange": () => true,
 		"SetFacePointAfterMove": () => {},
 		"GetFacePointAfterMove": () => true,
 		"GetPassabilityClassName": () => "default"
 	});
 
+	AddMock(SYSTEM_ENTITY, IID_Pathfinder, {
+		"GetClearance": () => 1,
+		"GetPassabilityClass": () => 16
+	});
+
 	controllerAI.OnCreate();
 
 
@@ -348,6 +358,7 @@ function TestMoveIntoFormationWhileAttacking()
 
 		AddMock(unit + i, IID_UnitMotion, {
 			"GetWalkSpeed": () => 1,
+			"GetAcceleration": () => 1,
 			"MoveToFormationOffset": (target, x, z) => {},
 			"MoveToTargetRange": (target, min, max) => true,
 			"SetMemberOfFormation": () => {},
@@ -386,7 +397,6 @@ function TestMoveIntoFormationWhileAttacking()
 	});
 
 	let controllerFormation = ConstructComponent(controller, "Formation", {
-		"FormationName": "Line Closed",
 		"FormationShape": "square",
 		"ShiftRows": "false",
 		"SortingClasses": "",
@@ -404,6 +414,7 @@ function TestMoveIntoFormationWhileAttacking()
 	AddMock(controller, IID_Position, {
 		"GetTurretParent": () => INVALID_ENTITY,
 		"JumpTo": function(x, z) { this.x = x; this.z = z; },
+		"TurnTo": function() {},
 		"GetPosition": function(){ return new Vector3D(this.x, 0, this.z); },
 		"GetPosition2D": function(){ return new Vector2D(this.x, this.z); },
 		"GetRotation": () => ({ "y": 0 }),
@@ -414,6 +425,8 @@ function TestMoveIntoFormationWhileAttacking()
 	AddMock(controller, IID_UnitMotion, {
 		"GetWalkSpeed": () => 1,
 		"SetSpeedMultiplier": (speed) => {},
+		"SetAcceleration": (accel) => {},
+		"SetPassabilityClassName": (name) => {},
 		"MoveToPointRange": (x, z, minRange, maxRange) => {},
 		"StopMoving": () => {},
 		"SetFacePointAfterMove": () => {},
@@ -421,6 +434,11 @@ function TestMoveIntoFormationWhileAttacking()
 		"GetPassabilityClassName": () => "default"
 	});
 
+	AddMock(SYSTEM_ENTITY, IID_Pathfinder, {
+		"GetClearance": () => 1,
+		"GetPassabilityClass": () => 16
+	});
+
 	AddMock(controller, IID_Attack, {
 		"GetRange": function() { return { "max": 10, "min": 0 }; },
 		"CanAttackAsFormation": function() { return false; },
@@ -439,7 +457,7 @@ function TestMoveIntoFormationWhileAttacking()
 
 	// let all units be in position
 	for (let ent of unitAIs)
-		controllerFormation.SetWaitingOnController(ent);
+		controllerFormation.SetFinishedEntity(ent);
 
 	for (let ent of unitAIs)
 		TS_ASSERT_EQUALS(unitAI.fsmStateName, "INDIVIDUAL.COMBAT.ATTACKING");
