@@ -279,6 +279,27 @@ var g_Commands = {
 		}
 	},
 
+	"call-to-arms": function(player, cmd, data)
+	{
+		const unitsToMove = data.entities.filter(ent =>
+			MatchesClassList(Engine.QueryInterface(ent, IID_Identity).GetClassesList(),
+				["Soldier", "Warship", "Siege", "Healer"])
+		);
+		GetFormationUnitAIs(unitsToMove, player, cmd, data.formation).forEach(cmpUnitAI => {
+			const target = cmd.target;
+			if (cmd.pushFront)
+			{
+				cmpUnitAI.WalkAndFight(target.x, target.z, cmd.targetClasses, cmd.allowCapture, false, cmd.pushFront);
+				cmpUnitAI.DropAtNearestDropSite(false, cmd.pushFront);
+			}
+			else
+			{
+				cmpUnitAI.DropAtNearestDropSite(cmd.queued, false)
+				cmpUnitAI.WalkAndFight(target.x, target.z, cmd.targetClasses, cmd.allowCapture, true, false);
+			}
+		});
+	},
+
 	"remove-guard": function(player, cmd, data)
 	{
 		for (let ent of data.entities)
@@ -332,29 +353,19 @@ var g_Commands = {
 				continue;
 			}
 
-			var queue = Engine.QueryInterface(ent, IID_ProductionQueue);
+			const cmpTrainer = Engine.QueryInterface(ent, IID_Trainer);
+			if (!cmpTrainer)
+				continue;
+
+			let templateName = cmd.template;
 			// Check if the building can train the unit
 			// TODO: the AI API does not take promotion technologies into account for the list
 			// of trainable units (taken directly from the unit template). Here is a temporary fix.
-			if (queue && data.cmpPlayer.IsAI())
-			{
-				var list = queue.GetEntitiesList();
-				if (list.indexOf(cmd.template) === -1 && cmd.promoted)
-				{
-					for (var promoted of cmd.promoted)
-					{
-						if (list.indexOf(promoted) === -1)
-							continue;
-						cmd.template = promoted;
-						break;
-					}
-				}
-			}
-			if (queue && queue.GetEntitiesList().indexOf(cmd.template) != -1)
-				if ("metadata" in cmd)
-					queue.AddItem(cmd.template, "unit", +cmd.count, cmd.metadata);
-				else
-					queue.AddItem(cmd.template, "unit", +cmd.count);
+			if (data.cmpPlayer.IsAI())
+				templateName = cmpTrainer.GetUpgradedTemplate(cmd.template);
+
+			if (cmpTrainer.CanTrain(templateName))
+				Engine.QueryInterface(ent, IID_ProductionQueue)?.AddItem(templateName, "unit", +cmd.count, cmd.metadata, cmd.pushFront);
 		}
 	},
 
@@ -370,7 +381,7 @@ var g_Commands = {
 
 		var queue = Engine.QueryInterface(cmd.entity, IID_ProductionQueue);
 		if (queue)
-			queue.AddItem(cmd.template, "technology");
+			queue.AddItem(cmd.template, "technology", undefined, cmd.metadata, cmd.pushFront);
 	},
 
 	"stop-production": function(player, cmd, data)
@@ -952,9 +963,9 @@ function notifyOrderFailure(entity, player)
 	cmpGUIInterface.PushNotification({
 		"type": "text",
 		"players": [player],
-		"message": sprintf(markForTranslation("%(unit)s can't be controlled."), {
-			"unit": cmpIdentity.GetGenericName()
-		}),
+		"message": markForTranslation("%(unit)s can't be controlled."),
+		"parameters": { "unit": cmpIdentity.GetGenericName() },
+		"translateParameters": ["unit"],
 		"translateMessage": true
 	});
 }
@@ -1586,12 +1597,11 @@ function GetFormationUnitAIs(ents, player, cmd, formationTemplate, forceTemplate
 		if (!cmpUnitAI || !cmpPosition || !cmpPosition.IsInWorld())
 			continue;
 
-		let cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
 		// TODO: We only check if the formation is usable by some units
 		// if we move them to it. We should check if we can use formations
 		// for the other cases.
 		let nullFormation = (formationTemplate || cmpUnitAI.GetFormationTemplate()) == NULL_FORMATION;
-		if (nullFormation || !cmpIdentity || !cmpIdentity.CanUseFormation(formationTemplate || NULL_FORMATION))
+		if (nullFormation || !cmpUnitAI.CanUseFormation(formationTemplate || NULL_FORMATION))
 		{
 			if (nullFormation && cmpUnitAI.GetFormationController())
 				cmpUnitAI.LeaveFormation(cmd.queued || false);
@@ -1733,19 +1743,14 @@ function CanMoveEntsIntoFormation(ents, formationTemplate)
 	// TODO: should check the player's civ is allowed to use this formation
 	// See simulation/components/Player.js GetFormations() for a list of all allowed formations
 
-	var requirements = GetFormationRequirements(formationTemplate);
+	const requirements = GetFormationRequirements(formationTemplate);
 	if (!requirements)
 		return false;
 
-	var count = 0;
-	for (let ent of ents)
-	{
-		var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
-		if (!cmpIdentity || !cmpIdentity.CanUseFormation(formationTemplate))
-			continue;
-
-		++count;
-	}
+	let count = 0;
+	for (const ent of ents)
+		if (Engine.QueryInterface(ent, IID_UnitAI)?.CanUseFormation(formationTemplate))
+			++count;
 
 	return count >= requirements.minCount;
 }
