@@ -146,6 +146,36 @@ var g_OptionType = {
 			};
 		}
 	},
+	"dropdownNumber":
+	{
+		"configToValue": value => +value,
+		"valueToGui": (value, control) => {
+			control.selected = control.list_data.indexOf("" + value);
+		},
+		"guiToValue": control => +control.list_data[control.selected],
+		"guiSetter": "onSelectionChange",
+		"initGUI": (option, control) => {
+			control.list = option.list.map(e => e.label);
+			control.list_data = option.list.map(e => e.value);
+			control.onHoverChange = () => {
+				const item = option.list[control.hovered];
+				control.tooltip = item && item.tooltip || option.tooltip;
+			};
+		},
+		"timeout": (option, oldValue, hasChanges, newValue) => {
+			if (!option.timeout)
+				return;
+			timedConfirmation(
+				500, 200,
+				translate("Changes will be reverted in %(time)s seconds. Do you want to keep changes?"),
+				"time",
+				option.timeout,
+				translate("Warning"),
+				[translate("No"), translate("Yes")],
+				[() => {this.revertChange(option, +oldValue, hasChanges);}, null]
+			);
+		}
+	},
 	"slider":
 	{
 		"configToValue": value => +value,
@@ -242,14 +272,20 @@ function displayOptions()
 			if (optionType.sanitizeValue)
 				optionType.sanitizeValue(value, control, option);
 
+			const oldValue = optionType.configToValue(Engine.ConfigDB_GetValue("user", option.config));
+
 			control.tooltip = option.tooltip + (optionType.tooltip ? "\n" + optionType.tooltip(value, option) : "");
 
+			const hasChanges = Engine.ConfigDB_HasChanges("user");
 			Engine.ConfigDB_CreateValue("user", option.config, String(value));
 			Engine.ConfigDB_SetChanges("user", true);
 
 			g_ChangedKeys.add(option.config);
 			fireConfigChangeHandlers(new Set([option.config]));
 
+			if (option.timeout)
+				optionType.timeout(option, oldValue, hasChanges, value);
+
 			if (option.function)
 				Engine[option.function](value);
 
@@ -277,16 +313,29 @@ function displayOptions()
 function enableButtons()
 {
 	g_Options[g_TabCategorySelected].options.forEach((option, i) => {
+		const isDependencyMet = dependency => {
+			if (typeof dependency === "string")
+				return Engine.ConfigDB_GetValue("user", dependency) == "true";
+			else if (typeof dependency === "object")
+			{
+				const availableOps = {
+					"==": (config, value) => config == value,
+					"!=": (config, value) => config != value
+				};
+				const op = availableOps[dependency.op] || availableOps["=="];
+				return op(Engine.ConfigDB_GetValue("user", dependency.config), dependency.value);
+			}
+			error("Unsupported dependency: " + uneval(dependency));
+			return false;
+		};
 
-		let enabled =
-			!option.dependencies ||
-			option.dependencies.every(config => Engine.ConfigDB_GetValue("user", config) == "true");
+		const enabled = !option.dependencies || option.dependencies.every(isDependencyMet);
 
 		Engine.GetGUIObjectByName("option_label[" + i + "]").enabled = enabled;
 		Engine.GetGUIObjectByName("option_control_" + option.type + "[" + i + "]").enabled = enabled;
 	});
 
-	let hasChanges = Engine.ConfigDB_HasChanges("user");
+	const hasChanges = Engine.ConfigDB_HasChanges("user");
 	Engine.GetGUIObjectByName("revertChanges").enabled = hasChanges;
 	Engine.GetGUIObjectByName("saveChanges").enabled = hasChanges;
 }
@@ -315,6 +364,18 @@ function reallySetDefaults()
 	revertChanges();
 }
 
+function revertChange(option, oldValue, hadChanges)
+{
+	if (!hadChanges)
+		Engine.ConfigDB_SetChanges("user", false);
+
+	Engine.ConfigDB_CreateValue("user", option.config, String(oldValue));
+	if (option.function)
+		Engine[option.function](oldValue);
+
+	displayOptions();
+}
+
 function revertChanges()
 {
 	Engine.ConfigDB_Reload("user");
