@@ -194,7 +194,7 @@ placePlayerBases({
 		"innerTerrain": tRoad,
 		"radius": playerCanyonRadius / 3
 	},
-	"Chicken": {
+	"StartingAnimal": {
 	},
 	"Berries": {
 		"template": oFruitBush
@@ -285,11 +285,11 @@ createDecoration(
 		[new SimpleObject(aBushMedium, 1, 2, 0, 2), new SimpleObject(aBushSmall, 2, 4, 0, 2)]
 	],
 	[
-		3 * scaleByMapSize(16, 262),
-		3 * scaleByMapSize(8, 131),
-		planetm * scaleByMapSize(13, 200),
-		planetm * scaleByMapSize(13, 200),
-		planetm * scaleByMapSize(13, 200)
+		3 * scaleByMapAreaAbsolute(16),
+		3 * scaleByMapAreaAbsolute(8),
+		planetm * scaleByMapAreaAbsolute(13),
+		planetm * scaleByMapAreaAbsolute(13),
+		planetm * scaleByMapAreaAbsolute(13)
 	],
 	avoidClasses(clForest, 0, clPlayer, 0, clHill, 0));
 
