@@ -79,7 +79,7 @@ placePlayerBases({
 			new TileClassPainter(clPlayer)
 		]
 	},
-	"Chicken": {
+	"StartingAnimal": {
 	},
 	"Berries": {
 		"template": "gaia/fruit/grapes",
