@@ -228,7 +228,7 @@ placePlayerBases({
 		"outerTerrain": tRoad,
 		"innerTerrain": tRoad
 	},
-	"Chicken": {
+	"StartingAnimal": {
 	},
 	"Berries": {
 		"template": oBerryBush
