@@ -80,7 +80,7 @@ placePlayerBases({
 		"outerTerrain": tCityPlaza,
 		"innerTerrain": tCity
 	},
-	"Chicken": {
+	"StartingAnimal": {
 	},
 	"Berries": {
 		"template": oGrapeBush
