@@ -129,7 +129,7 @@ placePlayerBases({
 			new SmoothElevationPainter(ELEVATION_SET, heightPlayer, 2)
 		]
 	},
-	"Chicken": {
+	"StartingAnimal": {
 	},
 	"Berries": {
 		"template": g_Gaia.fruitBush
@@ -320,8 +320,8 @@ createDecoration(
 		[new SimpleObject(g_Decoratives.lillies, 1, 2, 0, 1)]
 	],
 	[
-		200 * Math.pow(scaleByMapSize(3, 12), 2),
-		100 * Math.pow(scaleByMapSize(3, 12), 2)
+		scaleByMapAreaAbsolute(1800),
+		scaleByMapAreaAbsolute(900)
 	],
 	new HeightConstraint(heightReedsMin, heightShoreline)
 );
