@@ -38,7 +38,7 @@ g_Terrains.additionalDirt1 = "desert_plants_b";
 g_Terrains.additionalDirt2 = "desert_sand_scrub";
 g_Gaia.tree1 = "gaia/tree/date_palm";
 g_Gaia.tree2 = "gaia/tree/senegal_date_palm";
-g_Gaia.tree3 = "gaia/fruit/fig";
+g_Gaia.tree3 = "gaia/fruit/date";
 g_Gaia.tree4 = "gaia/tree/cretan_date_palm_tall";
 g_Gaia.tree5 = "gaia/tree/cretan_date_palm_short";
 g_Gaia.fruitBush = "gaia/fruit/berry_05";
