@@ -114,7 +114,7 @@ placePlayerBases({
 		"outerTerrain": tRoadWild,
 		"innerTerrain": tRoad
 	},
-	"Chicken": {
+	"StartingAnimal": {
 		"template": oDeer,
 		"distance": 18,
 		"minGroupDistance": 2,
@@ -233,7 +233,7 @@ createDecoration(
 		]
 	],
 	[
-		scaleByMapSize(16, 262),
+		scaleByMapAreaAbsolute(16),
 		scaleByMapSize(40, 360)
 	],
 	avoidClasses(clWater, 2, clForest, 0, clPlayer, 20, clHill, 1));
