@@ -186,11 +186,11 @@ createDecoration(
 		[new SimpleObject(aBushMedium, 1, 2, 0, 2), new SimpleObject(aBushSmall, 2, 4, 0, 2)]
 	],
 	[
-		scaleByMapSize(16, 262),
-		scaleByMapSize(8, 131),
-		planetm * scaleByMapSize(13, 200),
-		planetm * scaleByMapSize(13, 200),
-		planetm * scaleByMapSize(13, 200)
+		scaleByMapAreaAbsolute(16),
+		scaleByMapAreaAbsolute(8),
+		planetm * scaleByMapAreaAbsolute(13),
+		planetm * scaleByMapAreaAbsolute(13),
+		planetm * scaleByMapAreaAbsolute(13)
 	],
 	[avoidClasses(clForest, 0, clPlayer, 0, clHill, 0), landConstraint]);
 Engine.SetProgress(90);
