@@ -638,13 +638,14 @@ function unknownPasses()
 	}
 
 	g_Map.log("Creating passages between neighboring players");
-	let passes = distributePointsOnCircle(numPlayers * 2, startAngle, fractionToTiles(0.35), mapCenter)[0];
-	for (let i = 0; i < numPlayers; ++i)
+	const passes = numPlayers == 2 && distributePointsOnCircle(numPlayers * 3, startAngle, fractionToTiles(0.35), mapCenter)[0];
+	for (let i = 0; i < numPlayers && numPlayers > 1; ++i)
 	{
+		// For numPlayers > 2 use the playerPosition to not end up inside the mountains.
 		createArea(
 			new PathPlacer(
-				passes[2 * i],
-				passes[2 * ((i + 1) % numPlayers)],
+				numPlayers == 2 ? passes[3 * i + 1] : playerPosition[i],
+				numPlayers == 2 ? passes[3 * i + 2] : playerPosition[(i + 1) % numPlayers],
 				scaleByMapSize(14, 24),
 				0.4,
 				3 * scaleByMapSize(1, 3),
@@ -1044,7 +1045,7 @@ function createUnknownPlayerBases()
 				new TileClassPainter(clPlayer)
 			]
 		},
-		"Chicken": {
+		"StartingAnimal": {
 		},
 		"Berries": {
 			"template": oFruitBush
