@@ -18,6 +18,7 @@ const ACTION_REPAIR = 2;
 const ACTION_GUARD = 3;
 const ACTION_PATROL = 4;
 const ACTION_OCCUPY_TURRET = 5;
+const ACTION_CALLTOARMS = 6;
 var preSelectedAction = ACTION_NONE;
 
 const INPUT_NORMAL = 0;
@@ -63,11 +64,6 @@ const g_FreehandSelection_MinLengthOfLine = 8;
  */
 const g_FreehandSelection_MinNumberOfUnits = 2;
 
-/**
- * Number of pixels the mouse can move before the action is considered a drag.
- */
-const g_MaxDragDelta = 4;
-
 /**
  * Used for remembering mouse coordinates at start of drag operations.
  */
@@ -95,6 +91,11 @@ const doublePressTime = 500;
 var doublePressTimer = 0;
 var prevHotkey = 0;
 
+function getMaxDragDelta()
+{
+	return Engine.ConfigDB_GetValue("user", "gui.session.dragdelta");
+}
+
 function updateCursorAndTooltip()
 {
 	let cursorSet = false;
@@ -179,14 +180,14 @@ function updateBuildingPlacementPreview()
 
 			if (placementSupport.attack && placementSupport.attack.Ranged)
 			{
-				let cmd = {
+				const cmd = {
 					"x": placementSupport.position.x,
 					"z": placementSupport.position.z,
 					"range": placementSupport.attack.Ranged.maxRange,
-					"elevationBonus": placementSupport.attack.Ranged.elevationBonus
+					"yOrigin": placementSupport.attack.Ranged.yOrigin
 				};
-				let averageRange = Math.round(Engine.GuiInterfaceCall("GetAverageRangeForBuildings", cmd) - cmd.range);
-				let range = Math.round(cmd.range);
+				const averageRange = Math.round(Engine.GuiInterfaceCall("GetAverageRangeForBuildings", cmd) - cmd.range);
+				const range = Math.round(cmd.range);
 				placementSupport.tooltipMessage = sprintf(translatePlural("Basic range: %(range)s meter", "Basic range: %(range)s meters", range), { "range": range }) + "\n" +
 					sprintf(translatePlural("Average bonus range: %(range)s meter", "Average bonus range: %(range)s meters", averageRange), { "range": averageRange });
 			}
@@ -579,8 +580,7 @@ function handleInputBeforeGui(ev, hoveredObject)
 		case "mousemotion":
 			// If the mouse moved far enough from the original click location,
 			// then switch to drag-orientation mode.
-			let maxDragDelta = 16;
-			if (g_DragStart.distanceTo(ev) >= maxDragDelta)
+			if (g_DragStart.distanceTo(ev) >= Math.square(getMaxDragDelta()))
 			{
 				inputState = INPUT_BUILDING_DRAG;
 				return false;
@@ -719,8 +719,7 @@ function handleInputBeforeGui(ev, hoveredObject)
 		switch (ev.type)
 		{
 		case "mousemotion":
-			let maxDragDelta = 16;
-			if (g_DragStart.distanceTo(ev) >= maxDragDelta)
+			if (g_DragStart.distanceTo(ev) >= Math.square(getMaxDragDelta()))
 				// Rotate in the direction of the cursor.
 				placementSupport.angle = placementSupport.position.horizAngleTo(Engine.GetTerrainAtScreenPoint(ev.x, ev.y));
 			else
@@ -859,13 +858,13 @@ function handleInputAfterGui(ev)
 					if (ev.hotkey.indexOf("selection.group.select.") == 0)
 					{
 						let sptr = ev.hotkey.split(".");
-						performGroup("snap", sptr[3]);
+						performGroup("snap", sptr[3] - 1);
 					}
 				}
 				else
 				{
 					let sptr = ev.hotkey.split(".");
-					performGroup(sptr[2], sptr[3]);
+					performGroup(sptr[2], sptr[3] - 1);
 
 					doublePressTimer = now;
 					prevHotkey = ev.hotkey;
@@ -921,7 +920,7 @@ function handleInputAfterGui(ev)
 		switch (ev.type)
 		{
 		case "mousemotion":
-			if (g_DragStart.distanceTo(ev) >= g_MaxDragDelta)
+			if (g_DragStart.distanceTo(ev) >= getMaxDragDelta())
 			{
 				inputState = INPUT_BANDBOXING;
 				return false;
@@ -1004,7 +1003,7 @@ function handleInputAfterGui(ev)
 		switch (ev.type)
 		{
 		case "mousemotion":
-			if (g_DragStart.distanceToSquared(ev) >= Math.square(g_MaxDragDelta))
+			if (g_DragStart.distanceToSquared(ev) >= Math.square(getMaxDragDelta()))
 			{
 				inputState = INPUT_UNIT_POSITION;
 				return false;
@@ -1169,7 +1168,7 @@ function popOneFromSelection(action)
 		));
 	if (unit)
 	{
-		g_Selection.removeList([unit]);
+		g_Selection.removeList([unit], false);
 		return [unit];
 	}
 	return null;
@@ -1401,9 +1400,9 @@ function OnTrainMouseWheel(dir)
 function getBuildingsWhichCanTrainEntity(entitiesToCheck, trainEntType)
 {
 	return entitiesToCheck.filter(entity => {
-		let state = GetEntityState(entity);
-		return state && state.production && state.production.entities.length &&
-			state.production.entities.indexOf(trainEntType) != -1 && (!state.upgrade || !state.upgrade.isUpgrading);
+		const state = GetEntityState(entity);
+		return state?.trainer?.entities?.includes(trainEntType) &&
+			(!state.upgrade || !state.upgrade.isUpgrading);
 	});
 }
 
@@ -1520,7 +1519,8 @@ function addTrainingToQueue(selection, trainEntType, playerState)
 			"type": "train",
 			"template": trainEntType,
 			"count": 1,
-			"entities": buildingsForTraining
+			"entities": buildingsForTraining,
+			"pushFront": Engine.HotkeyIsPressed("session.pushorderfront")
 		});
 	}
 }
@@ -1578,7 +1578,8 @@ function flushTrainingBatch()
 			"type": "train",
 			"entities": appropriateBuildings.slice(0, buildingsCountToTrainFullBatch),
 			"template": g_BatchTrainingType,
-			"count": batchedSize
+			"count": batchedSize,
+			"pushFront": Engine.HotkeyIsPressed("session.pushorderfront")
 		});
 
 		// Train remainer in one more structure.
@@ -1588,7 +1589,8 @@ function flushTrainingBatch()
 				"type": "train",
 				"entities": [appropriateBuildings[buildingsCountToTrainFullBatch]],
 				"template": g_BatchTrainingType,
-				"count": remainer
+				"count": remainer,
+				"pushFront": Engine.HotkeyIsPressed("session.pushorderfront")
 			});
 	}
 	else
@@ -1596,12 +1598,18 @@ function flushTrainingBatch()
 			"type": "train",
 			"entities": appropriateBuildings,
 			"template": g_BatchTrainingType,
-			"count": batchedSize
+			"count": batchedSize,
+			"pushFront": Engine.HotkeyIsPressed("session.pushorderfront")
 		});
 }
 
 function performGroup(action, groupId)
 {
+	if (g_Groups.groups[groupId] === undefined)
+	{
+		warn("Invalid groupId " + groupId);
+		return;
+	}
 	switch (action)
 	{
 	case "snap":
@@ -1619,7 +1627,7 @@ function performGroup(action, groupId)
 
 		if (action == "snap" && toSelect.length)
 		{
-			let entState = GetEntityState(toSelect[0]);
+			let entState = GetEntityState(getEntityOrHolder(toSelect[0]));
 			let position = entState.position;
 			if (position && entState.visibility != "hidden")
 				Engine.CameraMoveTo(position.x, position.z);
