@@ -242,13 +242,13 @@ g_SelectionPanels.Formation = {
 		if (unitEntStates.some(state => !hasClass(state, "Unit")))
 			return [];
 
-		if (unitEntStates.every(state => !state.identity || !state.identity.hasSomeFormation))
+		if (unitEntStates.every(state => !state.unitAI || !state.unitAI.formations.length))
 			return [];
 
 		if (!g_AvailableFormations.has(unitEntStates[0].player))
 			g_AvailableFormations.set(unitEntStates[0].player, Engine.GuiInterfaceCall("GetAvailableFormations", unitEntStates[0].player));
 
-		return g_AvailableFormations.get(unitEntStates[0].player).filter(formation => unitEntStates.some(state => !!state.identity && state.identity.formations.indexOf(formation) != -1));
+		return g_AvailableFormations.get(unitEntStates[0].player).filter(formation => unitEntStates.some(state => !!state.unitAI && state.unitAI.formations.includes(formation)));
 	},
 	"setupButton": function(data)
 	{
@@ -569,10 +569,16 @@ g_SelectionPanels.Queue = {
 
 		data.countDisplay.caption = queuedItem.count > 1 ? queuedItem.count : "";
 
+		const progressSlider = Engine.GetGUIObjectByName("unitQueueProgressSlider[" + data.i + "]");
 		if (data.item.ghost)
 		{
 			data.button.enabled = false;
-			Engine.GetGUIObjectByName("unitQueueProgressSlider[" + data.i + "]").sprite="color:0 150 250 50";
+			progressSlider.sprite="color:0 150 250 50";
+			const size = progressSlider.size;
+
+			// Buttons are assumed to be square, so left/right offsets can be used for top/bottom.
+			size.top = size.left;
+			progressSlider.size = size;
 		}
 		else
 		{
@@ -581,19 +587,30 @@ g_SelectionPanels.Queue = {
 				Engine.GetGUIObjectByName("queueTimeRemaining").caption =
 					Engine.FormatMillisecondsIntoDateStringGMT(queuedItem.timeRemaining, translateWithContext("countdown format", "m:ss"));
 
-			const guiObject = Engine.GetGUIObjectByName("unitQueueProgressSlider[" + data.i + "]");
-			guiObject.sprite = "queueProgressSlider";
-			const size = guiObject.size;
+			progressSlider.sprite = "queueProgressSlider";
+			const size = progressSlider.size;
 
 			// Buttons are assumed to be square, so left/right offsets can be used for top/bottom.
 			size.top = size.left + Math.round(queuedItem.progress * (size.right - size.left));
-			guiObject.size = size;
+			progressSlider.size = size;
 
 			data.button.enabled = controlsPlayer(data.player);
+
+			Engine.GetGUIObjectByName("unitQueuePausedIcon[" + data.i + "]").hidden = !queuedItem.paused;
+			if (queuedItem.paused)
+				// Translation: String displayed when the research is paused. E.g. by being garrisoned or when not the first item in the queue.
+				data.button.tooltip += "\n" + translate("This item is paused.");
 		}
 
 		if (template.icon)
-			data.icon.sprite = (data.item.ghost ? "grayscale:" : "") + "stretched:session/portraits/" + template.icon;
+		{
+			let modifier = "stretched:";
+			if (queuedItem.paused)
+				modifier += "color:0 0 0 127:grayscale:";
+			else if (data.item.ghost)
+				modifier += "grayscale:";
+			data.icon.sprite = modifier + "session/portraits/" + template.icon;
+		}
 
 
 		const showTemplateFunc = () => { showTemplateDetails(data.item.queuedItem.unitTemplate || data.item.queuedItem.technologyTemplate, data.playerState.civ); };
@@ -615,13 +632,19 @@ g_SelectionPanels.Research = {
 	{
 		let ret = [];
 		if (unitEntStates.length == 1)
-			return !unitEntStates[0].production || !unitEntStates[0].production.technologies ? ret :
-				unitEntStates[0].production.technologies.map(tech => ({
-					"tech": tech,
-					"techCostMultiplier": unitEntStates[0].production.techCostMultiplier,
-					"researchFacilityId": unitEntStates[0].id,
-					"isUpgrading": !!unitEntStates[0].upgrade && unitEntStates[0].upgrade.isUpgrading
-				}));
+		{
+			const entState = unitEntStates[0];
+			if (!entState?.researcher?.technologies)
+				return ret;
+			if (!entState.production)
+				warn("Researcher without ProductionQueue found: " + entState.id + ".");
+			return entState.researcher.technologies.map(tech => ({
+				"tech": tech,
+				"techCostMultiplier": entState.researcher.techCostMultiplier,
+				"researchFacilityId": entState.id,
+				"isUpgrading": !!entState.upgrade && entState.upgrade.isUpgrading
+			}));
+		}
 
 		let sortedEntStates = unitEntStates.sort((a, b) =>
 			(!b.upgrade || !b.upgrade.isUpgrading) - (!a.upgrade || !a.upgrade.isUpgrading) ||
@@ -630,11 +653,13 @@ g_SelectionPanels.Research = {
 
 		for (let state of sortedEntStates)
 		{
-			if (!state.production || !state.production.technologies)
+			if (!state.researcher || !state.researcher.technologies)
 				continue;
+			if (!state.production)
+				warn("Researcher without ProductionQueue found: " + state.id + ".");
 
 			// Remove the techs we already have in ret (with the same name and techCostMultiplier)
-			let filteredTechs = state.production.technologies.filter(
+			const filteredTechs = state.researcher.technologies.filter(
 				tech => tech != null && !ret.some(
 					item =>
 						(item.tech == tech ||
@@ -643,14 +668,14 @@ g_SelectionPanels.Research = {
 							item.tech.bottom == tech.bottom &&
 							item.tech.top == tech.top) &&
 						Object.keys(item.techCostMultiplier).every(
-							k => item.techCostMultiplier[k] == state.production.techCostMultiplier[k])
+							k => item.techCostMultiplier[k] == state.researcher.techCostMultiplier[k])
 				));
 
 			if (filteredTechs.length + ret.length <= this.getMaxNumberOfItems() &&
 			    getNumberOfRightPanelButtons() <= this.getMaxNumberOfItems() * (filteredTechs.some(tech => !!tech.pair) ? 1 : 2))
 				ret = ret.concat(filteredTechs.map(tech => ({
 					"tech": tech,
-					"techCostMultiplier": state.production.techCostMultiplier,
+					"techCostMultiplier": state.researcher.techCostMultiplier,
 					"researchFacilityId": state.id,
 					"isUpgrading": !!state.upgrade && state.upgrade.isUpgrading
 				})));
@@ -705,7 +730,7 @@ g_SelectionPanels.Research = {
 			}
 
 			for (let res in template.cost)
-				template.cost[res] *= data.item.techCostMultiplier[res];
+				template.cost[res] *= data.item.techCostMultiplier[res] !== undefined ? data.item.techCostMultiplier[res] : 1;
 
 			let neededResources = Engine.GuiInterfaceCall("GetNeededResources", {
 				"cost": template.cost,
@@ -901,8 +926,13 @@ g_SelectionPanels.Selection = {
 
 		data.countDisplay.caption = data.item.ents.length || "";
 
-		data.button.onPress = function() { changePrimarySelectionGroup(data.item.key, false); };
-		data.button.onPressRight = function() { changePrimarySelectionGroup(data.item.key, true); };
+		data.button.onPress = function() {
+			if (Engine.HotkeyIsPressed("session.deselectgroup"))
+				removeFromSelectionGroup(data.item.key);
+			else
+				makePrimarySelectionGroup(data.item.key);
+		};
+		data.button.onPressRight = function() { removeFromSelectionGroup(data.item.key); };
 
 		if (template.icon)
 			data.icon.sprite = "stretched:session/portraits/" + template.icon;
