@@ -136,12 +136,14 @@ function formatMatchLimitString(matchEntLimit, matchEntCount, type)
 	let text;
 	if (type == "build")
 	{
-		if (passedLimit)
-			text = sprintf(translatePlural("Could only be constructed once.", "Could only be constructed %(limit)s times.", matchEntLimit), {
-				"limit": matchEntLimit
-			});
-		else if (matchEntLimit == 1)
+		if (matchEntLimit == 1)
 			text = translate("Can be constructed only once.");
+		else if (passedLimit)
+			text = sprintf(translatePlural(
+				"Could only be constructed %(limit)s time.",
+				"Could only be constructed %(limit)s times.",
+				matchEntLimit),
+			{ "limit": matchEntLimit });
 		else
 			text = sprintf(translatePlural("Can be constructed %(count)s more time.", "Can be constructed %(count)s more times.", count), {
 				"count": count
@@ -272,7 +274,8 @@ function addResearchToQueue(entity, researchType)
 	Engine.PostNetworkCommand({
 		"type": "research",
 		"entity": entity,
-		"template": researchType
+		"template": researchType,
+		"pushFront": Engine.HotkeyIsPressed("session.pushorderfront")
 	});
 }
 
@@ -291,10 +294,14 @@ function removeFromProductionQueue(entity, id)
 /**
  * Called by unit selection buttons.
  */
-function changePrimarySelectionGroup(templateName, deselectGroup)
+function makePrimarySelectionGroup(templateName)
 {
-	g_Selection.makePrimarySelection(templateName,
-		Engine.HotkeyIsPressed("session.deselectgroup") || deselectGroup);
+	g_Selection.makePrimarySelection(templateName);
+}
+
+function removeFromSelectionGroup(templateName)
+{
+	g_Selection.removeGroupFromSelection(templateName);
 }
 
 function performCommand(entStates, commandName)
@@ -553,7 +560,7 @@ function turnAutoQueueOn()
 		"type": "autoqueue-on",
 		"entities": g_Selection.filter(ent => {
 			let state = GetEntityState(ent);
-			return !!state?.production?.entities.length &&
+			return !!state?.trainer?.entities?.length &&
 				!state.production.autoqueue;
 		})
 	});
@@ -565,7 +572,7 @@ function turnAutoQueueOff()
 		"type": "autoqueue-off",
 		"entities": g_Selection.filter(ent => {
 			let state = GetEntityState(ent);
-			return !!state?.production?.entities.length &&
+			return !!state?.trainer?.entities?.length &&
 				state.production.autoqueue;
 		})
 	});
