@@ -118,7 +118,7 @@ var g_UnitActions =
 			DrawTargetMarker(target);
 
 			Engine.GuiInterfaceCall("PlaySound", {
-				"name": "order_walk",
+				"name": "order_attack_move",
 				"entity": action.firstAbleEntity
 			});
 
@@ -246,6 +246,53 @@ var g_UnitActions =
 		"specificness": 10,
 	},
 
+	"call-to-arms": {
+		"execute": function(target, action, selection, queued, pushFront)
+		{
+			let targetClasses;
+			if (Engine.HotkeyIsPressed("session.attackmoveUnit"))
+				targetClasses = { "attack": ["Unit"] };
+			else
+				targetClasses = { "attack": ["Unit", "Structure"] };
+			Engine.PostNetworkCommand({
+				"type": "call-to-arms",
+				"entities": selection,
+				"target": target,
+				"targetClasses": targetClasses,
+				"queued": queued,
+				"pushFront": pushFront,
+				"allowCapture": true,
+				"formation": g_AutoFormation.getNull()
+			});
+			return true;
+		},
+		"getActionInfo": function(entState, targetState)
+		{
+			return { "possible": !!entState.unitAI };
+		},
+		"actionCheck": function(target, selection)
+		{
+			const actionInfo = getActionInfo("call-to-arms", target, selection);
+			return actionInfo.possible && {
+				"type": "call-to-arms",
+				"cursor": "action-attack",
+				"target": target,
+				"firstAbleEntity": actionInfo.entity
+			};
+		},
+		"hotkeyActionCheck": function(target, selection)
+		{
+			return Engine.HotkeyIsPressed("session.calltoarms") &&
+				this.actionCheck(target, selection);
+		},
+		"preSelectedActionCheck": function(target, selection)
+		{
+			return preSelectedAction == ACTION_CALLTOARMS &&
+				this.actionCheck(target, selection);
+		},
+		"specificness": 50,
+	},
+
 	"patrol":
 	{
 		"execute": function(target, action, selection, queued, pushFront)
@@ -1011,8 +1058,8 @@ var g_UnitActions =
 			// Don't allow the rally point to be set on any of the currently selected entities (used for unset)
 			// except if the autorallypoint hotkey is pressed and the target can produce entities.
 			if (targetState && (!Engine.HotkeyIsPressed("session.autorallypoint") ||
-			    !targetState.production ||
-			    !targetState.production.entities.length))
+			    !targetState.trainer ||
+			    !targetState.trainer.entities.length))
 				for (const ent of g_Selection.toList())
 					if (targetState.id == ent)
 						return false;
@@ -1107,9 +1154,9 @@ var g_UnitActions =
 			{
 				// Find a trader (if any) that this structure can train.
 				let trader;
-				if (entState.production && entState.production.entities.length)
-					for (let i = 0; i < entState.production.entities.length; ++i)
-						if ((trader = GetTemplateData(entState.production.entities[i]).trader))
+				if (entState.trainer?.entities?.length)
+					for (let i = 0; i < entState.trainer.entities.length; ++i)
+						if ((trader = GetTemplateData(entState.trainer.entities[i]).trader))
 							break;
 
 				let traderData = {
@@ -1423,6 +1470,27 @@ var g_EntityCommands =
 		"allowedPlayers": ["Player"]
 	},
 
+	"call-to-arms": {
+		"getInfo": function(entStates)
+		{
+			const classes = ["Soldier", "Warship", "Siege", "Healer"];
+			if (entStates.every(entState => !MatchesClassList(entState.identity.classes, classes)))
+				return false;
+			return {
+				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.calltoarms") +
+						translate("Send the selected units on attack move to the specified location after dropping resources."),
+				"icon": "call-to-arms.png",
+				"enabled": true
+			};
+		},
+		"execute": function(entStates)
+		{
+			inputState = INPUT_PRESELECTEDACTION;
+			preSelectedAction = ACTION_CALLTOARMS;
+		},
+		"allowedPlayers": ["Player"]
+	},
+
 	"garrison": {
 		"getInfo": function(entStates)
 		{
@@ -1725,7 +1793,7 @@ var g_EntityCommands =
 	"autoqueue-on": {
 		"getInfo": function(entStates)
 		{
-			if (entStates.every(entState => !entState.production || !entState.production.entities.length || entState.production.autoqueue))
+			if (entStates.every(entState => !entState.trainer?.entities?.length || !entState.production || entState.production.autoqueue))
 				return false;
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.queueunit.autoqueueon") +
@@ -1745,7 +1813,7 @@ var g_EntityCommands =
 	"autoqueue-off": {
 		"getInfo": function(entStates)
 		{
-			if (entStates.every(entState => !entState.production || !entState.production.entities.length || !entState.production.autoqueue))
+			if (entStates.every(entState => !entState.production?.autoqueue))
 				return false;
 			return {
 				"tooltip": colorizeHotkey("%(hotkey)s" + " ", "session.queueunit.autoqueueoff") +
